/* This program 
 * 1) Creates a userinfo Object of Super admin User.
 * 2) Get all report categories from the report server
 *User would require to use following Intellicus jar files for using Intellicus APIs:
 * 1) intellica.jar
 * 2) log4ij.jar
 * 3) xercesImpl.jar
 * 4) xmlParserAPIs.jar
 * Place above jar files in the classpath of your application.
 * These jar files are located at  :  <Install_Path>\Intellicus\APIs
 */

/***
 * DISCLAIMER OF WARRANTY
 * This source code is provided "as is" and without warranties as to performance or merchantability. 
 * 
 * This source code is provided without any express or implied warranties whatsoever
 *
**/


// Import Section
// Use intellica jar to import these classes
import com.intellica.client.init.ReportClient; // Has Init Method
import com.intellica.client.common.Enums;
import com.intellica.client.common.Filter;
import com.intellica.client.common.UserInfo; // user info bean 
import com.intellica.client.utils.HashContainer; // Object used to pass parameters collection
import com.intellica.client.layout.LayoutManager;// for report layout management related operations			 
import com.intellica.client.reportutils.Category; //This class represents the Report Category.
import com.intellica.client.exception.LayoutHandlerException;//This Exception class is used for all Layout use cases.
import java.util.Vector;//The Vector class implements a growable array of objects. Like an array, it contains components
                        //that can be accessed using an integer index.
import 	java.io.FileInputStream;
import 	java.io.BufferedInputStream;
import 	java.io.InputStream;

//This class retrieves the list of categories from the Intellicus repository.
public class GetCategoryList
{
	public static void main(String args[])
	{
		try
		{
	
				// Static Init call. it will read the properties for report server related attributes 
				// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
				//in the INTERA_HOME property of the ReportClient.properties file.
				InputStream is= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																														//with the absolute path of ReportClient.properties.
				ReportClient.init(is);
			
			// Prepare a requestor user info bean object.
			// This user must have Admin rights to perform user management actions
			// such as create user
			// This user should be present in Intellicus application.
			//Syntax public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
            //@param userId   - : Id of the User Logged-In.
            //@param password - : Password of the User Logged-In.
            //@param orgId    - : Organization Id from which User Logged-In.
			String userId = "Admin";
			String password = "Admin";
			String organization = "Intellica";
		    UserInfo requestorUserInfo	=	new UserInfo(userId,password,organization);
			
			// Create a Layout Manager class object 
			// for report layout management related operations			
			LayoutManager lm= new LayoutManager();
						
			Vector vecCatList= new Vector();
            Filter filterObj = new Filter();
            filterObj.setFilterField(Enums.Filters.CategoryList.OWNERAPPID, requestorUserInfo.getUserId());
            filterObj.setFilterField(Enums.Filters.CategoryList.OWNERORGID, requestorUserInfo.getOrganization());

			try
			{
				// This will return vector of category object
				vecCatList=lm.getCategoryList(filterObj, requestorUserInfo);
			
			}
			catch (LayoutHandlerException e)
			{
			    System.out.println ("ErrorMessage: "+e.getMessage());
			    System.out.println ("RootCause	 : "+e.getRootCause());
			}
	
			if(vecCatList!=null)
			{
				for(int i=0; i<vecCatList.size(); i++)
			 	{								
					Category category = (Category)vecCatList.get(i);	
					System.out.println ("CategoryName: "+category.getMenuName());
					System.out.println ("CategoryId : "+category.getCategoryId());
					System.out.println ("Description: "+category.getDescription());
					System.out.println ("IsPublic: "+category.getIsPublic());
					System.out.println ("OwnerAppId: "+category.getOwnerAppId());
					System.out.println ("OwnerOrgId: "+category.getOwnerOrgId());
					System.out.println ("RepositDate: "+category.getRepositDate());
					System.out.println ();
				}
		   }
 		   else
 		    {
 			 System.out.println ("No category exits");	
 		    }	
		 }
		catch(Exception e)
		{
			e.printStackTrace();
		}
	}
}		
