/*
 * This program 
 *Send request to intellicus engine to create a Database connection.
 *it will create a Database connection with specified name
 */
//User would require to use following Intellicus jar files for using Intellicus APIs:
//1) intellica.jar
//2) log4ij.jar
//3) xercesImpl.jar
//4) xmlParserAPIs.jar
//Place above jar files in the classpath of your application.
//These jar files are located at  :  <Install_Path>\Intellicus\APIs
 
/***
 * DISCLAIMER OF WARRANTY
 * This source code is provided "as is" and without warranties as to performance or merchantability. 
 * 
 * This source code is provided without any express or implied warranties whatsoever
 *
**/

//Import Section

import java.util.HashMap;
import java.io.FileInputStream;
import java.io.BufferedInputStream;
import java.io.InputStream;

//Use intellica jar to import these classes
import com.intellica.client.common.DBConnection;//This class stores the information regarding a database connection.
import com.intellica.client.common.DBDriver;//For creating DBDriver object
import com.intellica.client.common.UserInfo;//For getting user information
import com.intellica.client.common.Enums.Filters.Olap;
import com.intellica.client.exception.LayoutHandlerException;//This Exception class is used 
                                                             //for all Layout use cases.
import com.intellica.client.init.ReportClient;// Has Init Method
import com.intellica.client.layout.LayoutManager;//For all report layout operations 
												 //client creates the object of this class.
												 //The methods of this class are stateless 
												 //and takes all required information such 
												 //as requestor User Info etc. in each call.
import com.intellica.client.olap.OLAPManager;
import com.intellica.client.olap.OlapData;

/*
 * This class is used to create a Database Connection in the Intellicus Repository
 */
public class CreateOlapConnection {
	public static void main(String[] args) {
		try{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
			InputStream is= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																														//with the absolute path of ReportClient.properties.
			ReportClient.init(is);

			//Making an object of DBDriver 
			DBDriver driverDB = new DBDriver();
			//Making an object of hashmap for DBDriver
			HashMap hMap = new HashMap();
			//setting DB driver URL for making a connection
			driverDB.setUrl("jdbc:xmla:server=http://192.168.33.142:9010/mondrianlatest/xmla");
			//Set Databse Provider for Olap MSAS/MONDRIAN
			driverDB.setProvider("MSAS");
			//Setting DataBase properties in hashmap
			//Set server IP
			hMap.put("SERVER","192.168.33.142");
			//Set  server port
			hMap.put("PORT", "9010");
			hMap.put("CATALOG","FoodMart");
			hMap.put("PATH","mondrianlatest/xmla");
			//setting hashmap in attribute hashmap
			driverDB.setAttrHash(hMap);
			//Making an object of DBConnection 
			DBConnection dbConn = new DBConnection();
			//setting DBDriver in DBConnection object 
			dbConn.setDbDriver(driverDB);
			//setting connection name that is going to established
			dbConn.setConnectionName("DeleteThisConnection");
			//Setting the connection type db/olap, if not specified it will create db connection by default.
			dbConn.setConnectionType("olap");
			
			/*Setting the number of connections to open when the all open 
			 *connections are consumed.  For example, if 10 connections are presently opened and 
			 *Incremental Size is 3, then when these 10 connections are consumed, 3 more connections will be opened
			*/
			dbConn.setIncrementSize("8");
			//Setting the time after which the connection is submitted after being idle.
			dbConn.setResubmitIdleTime("5");
			//Setting maximum number of possible connections.
			dbConn.setMaxConnections("30");
			//Setting initial number of connections.
			dbConn.setInitialConnections("10");
			//Setting the olap connection as a default olap connection
			dbConn.setIsDefaultOLAP(false);
			// Prepare a requestor user info bean object.
			// This user must have Admin rights to perform user management actions
			// such as create user
			// This user should be present in Intellicus application.
			//Syntax public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
            //@param userId   - : Id of the User Logged-In.
            //@param password - : Password of the User Logged-In.
            //@param orgId    - : Organization Id from which User Logged-In.
			UserInfo reqUserInfo = new UserInfo("Admin","Admin","Intellica");
			//Create a Layout Manager class object 
			// for report layout management related operations	
			LayoutManager lyoutMger = new LayoutManager();
			//To create new DB connection.
			//Syntax: public void addReportServerConnection(DBConnection dbConn,UserInfo userInfo)             
            //@param DBConnection -  The DBConnection object which is to be created 
            //@param userInfo    -  The current user details 
			//DBConnection object have sufficient information for creating a new connection
			
			lyoutMger.addReportServerConnection(dbConn,reqUserInfo);					
		}
		catch (LayoutHandlerException lhe)
		{
			System.out.println ("ErrorMessage: "+lhe.getMessage());
			 System.out.println ("RootCause	 : "+lhe.getRootCause());
		}
		catch(Exception e)
		{
			System.out.println("Exception is "+e);
		}
	}
}
