/*
 * This Java API is used to delete an existing Database Connection from the Intellicus Repository
 * User would require to use following Intellicus jar files for using Intellicus APIs:
 * 1) intellica.jar
 * 2) log4ij.jar
 * 3) xercesImpl.jar
 * 4) xmlParserAPIs.jar
 * Place above jar files in the classpath of your application.
 * These jar files are located at  :  <Install_Path>\Intellicus\APIs
 */



/***
 * DISCLAIMER OF WARRANTY
 * This source code is provided "as is" and without warranties as to performance or merchantability. 
 * 
 * This source code is provided without any express or implied warranties whatsoever
 *
**/

import java.util.ArrayList;//Array list related operations
import java.util.HashMap;//This class makes no guarantees as to the order of the map; in particular, 
						 //it does not guarantee that the order will remain constant over time. 
import java.util.Iterator;//An iterator over a collection. Iterator takes the place of Enumeration 
						  //in the Java collections framework.
import java.util.Set;//A collection that contains no duplicate elements.The Set interface places 
					 //additional stipulations, beyond those inherited from the Collection interface,
			         //on the contracts of all constructors and on the contracts of the add, equals and
					 //hashCode methods.
import java.io.FileInputStream;
import java.io.BufferedInputStream;
import java.io.InputStream;

//Use intellica jar to import these classes
import com.intellica.client.common.DBConnection;//This class stores the information regarding a database connection.
import com.intellica.client.common.Filter;
import com.intellica.client.common.UserInfo;// user info bean
import com.intellica.client.exception.LayoutHandlerException;
import com.intellica.client.init.ReportClient;// Has Init Method
import com.intellica.client.layout.LayoutManager;//For all report layout operations 
												 //client creates the object of this class.
												 //The methods of this class are stateless 
												 //and takes all required information such 
												 //as requestor User Info etc. in each call.



/*
 * This class is used to delete an existing Database Connection from the Intellicus Repository
 */
public class DeleteConnection{

	public static void main(String args[])
	{
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
			InputStream is= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																														//with the absolute path of ReportClient.properties.
			ReportClient.init(is);
			
            //Prepare a requestor user info bean object.
			// This user should be present in Intellicus application.
			//Syntax public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
            //@param userId   - : Id of the User Logged-In.
            //@param password - : Password of the User Logged-In.
            //@param orgId    - : Organization Id from which User Logged-In.
			String userId = "Admin";
			String password = "Admin";
			String organization = "Intellica";
		    UserInfo requestorUserInfo	=	new UserInfo(userId,password,organization);
			
			//Connection i.e. to be deleted
		    String connectionName = "MyConnection";
			
			// Create a Layout Manager class object 
			// for report layout management related operations			
			LayoutManager lmanager = new LayoutManager();
			
			
			HashMap map = new HashMap();
			Filter filter =new Filter();
			//For Filter CONNECTION_TYPE=ALL/OLAP ,if nothing is set in the filter only db connections are considered. 
			filter.setFilterField("CONNECTION_TYPE","ALL");
			
			//Syntax :public java.util.HashMap getDBConnectionList(Filter filter,UserInfo userInfo)
            //Returns the list of DB connections from the Intellicus Repository.
			//It is mandatory to pass filter as a parameter , if olap connection is required to be deleted 
			//As if no filter is passed then,the db connections can be deleted only.
			map=lmanager.getDBConnectionList(filter,requestorUserInfo);
			Set s=map.keySet();
			Iterator itr=s.iterator();
			
			
			//Iterating through the map 
			while(itr.hasNext())
			{
				ArrayList l=(ArrayList)(map.get(itr.next()));
				
				//Iterating through the List
				for(int i=0;i<l.size();i++)
				{
					Object o=l.get(i);
					
					// ArrayList contains both DBConnection and DBProvider class type
					// When class type is DBConnection
					if("class com.intellica.client.common.DBConnection".equalsIgnoreCase(String.valueOf(o.getClass())))
					{
						//This class stores the information regarding a database connection 
						DBConnection dbConn=(DBConnection)l.get(i);
						
						// Check whether the Connection i.e. to be deleted exists or not
						if(connectionName.equalsIgnoreCase(dbConn.getConnectionName()))
						{
							try
							{
								// The method delete given Report Server Connection 
								// Syntax : public java.lang.String deleteReportServerConnection(DBConnection dbConnection, UserInfo userInfo)
								// @ param dbConnection : DBConnection object which needs to be deleted.
								// @ param userInfo : The UserInfo object  
								lmanager.deleteReportServerConnection(dbConn, requestorUserInfo);
							
							}
							catch(LayoutHandlerException lhException)
							{
								lhException.printStackTrace();
							}
						}//end inner if
				   }//end Outer if
				}//end for
				
			}//end while loop
		
		            
		}
		catch(Exception e)
		{
			e.printStackTrace();
		}
	}	
}
