/*
 * This program returns the list of all the DB connections present in the Intellicus Repository.
 * User would also require to use following Intellicus jar files for using Intellicus APIs:
* 1) intellica.jar
* 2) log4ij.jar
* 3) xercesImpl.jar
* 4) xmlParserAPIs.jar
* Place above jar files in the classpath of your application.
* These jar files are located at  :  <Install_Path>\Intellicus\APIs
*/
 
/***
 * DISCLAIMER OF WARRANTY
 * This source code is provided "as is" and without warranties as to performance or merchantability. 
 * 
 * This source code is provided without any express or implied warranties whatsoever
 *
**/
//Use intellica jar to import these classes
import com.intellica.client.common.DBConnection;//This class stores the information regarding a database connection.
import com.intellica.client.common.Filter;
import com.intellica.client.common.UserInfo;// user info bean
import com.intellica.client.exception.LayoutHandlerException;
import com.intellica.client.init.ReportClient;// Has Init Method
import com.intellica.client.layout.LayoutManager;//For all report layout operations 
												 //client creates the object of this class.
												//The methods of this class are stateless 
												//and takes all required information such 
												//as requestor User Info etc. in each call.

import java.util.ArrayList;//Array list related operations
import java.util.HashMap;//This class makes no guarantees as to the order of the map; in particular, 
						//it does not guarantee that the order will remain constant over time. 

import java.util.Iterator;//An iterator over a collection. Iterator takes the place of Enumeration 
                          //in the Java collections framework.
import java.util.Set;//A collection that contains no duplicate elements.The Set interface places 
                     //additional stipulations, beyond those inherited from the Collection interface,
                     //on the contracts of all constructors and on the contracts of the add, equals and
                     //hashCode methods. 
import java.io.FileInputStream;
import java.io.BufferedInputStream;
import java.io.InputStream;

/*
 *This class returns the list of all the DB connections present in the Intellicus Repository.
 *
 */

public class GetConnectionList {

	public static void main(String args[])
	{
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
			InputStream is= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																														//with the absolute path of ReportClient.properties.
			ReportClient.init(is);
			
            //Prepare a requestor user info bean object.
			// This user should be present in Intellicus application.
			//Syntax public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
            //@param userId   - : Id of the User Logged-In.
            //@param password - : Password of the User Logged-In.
            //@param orgId    - : Organization Id from which User Logged-In.
			String userId = "Admin";
			String password = "Admin";
			String organization = "Intellica";
		    UserInfo requestorUserInfo	=	new UserInfo(userId,password,organization);
			
			//Create a Layout Manager class object 
			// for report layout management related operations			
			LayoutManager lm = new LayoutManager();
			
			HashMap map = new HashMap();
			
			Filter filter = new Filter();
			
			//CONNECTION_TYPE =ALL/OLAP is set as filter
			filter.setFilterField("CONNECTION_TYPE","ALL");
			//Syntax :public java.util.HashMap getDBConnectionList(Filter arg0,UserInfo userInfo)
            //Returns the list of DB connections from the Intellicus Repository.
			map=lm.getDBConnectionList(filter,requestorUserInfo);
			Set s=map.keySet();
			Iterator itr=s.iterator();
						
            //Iterating through the map
			while(itr.hasNext())
			{
				ArrayList l=(ArrayList)(map.get(itr.next()));
				
				//Iterating through the List
				for(int i=0;i<l.size();i++)
				{
					Object o=l.get(i);
					
					//ArrayList contains both DBConnection and DBProvider class type
					//When class type is DBConnection

					if("class com.intellica.client.common.DBConnection".equalsIgnoreCase(String.valueOf(o.getClass())))
					{
						//This class stores the information regarding a database connection 
					    DBConnection dbConn=(DBConnection)l.get(i);
					    //The following lists the properties of the connection like Connection nam , Connection Type etc...
						System.out.println("Connection Name  :  "+dbConn.getConnectionName());//Get the connection name
						System.out.println("Connection Type  :  "+dbConn.getConnectionType());//Get the connection type like DB,Olap etc.
						
						//getAdminStatus();Retuns valid if connection is valid if connetion is invalid returns invalid
						System.out.println("Admin Status  :  "+dbConn.getAdminStatus());
						
						System.out.println("Character Set Encoding  :  "+dbConn.getCharsetEncoding());//Get Character Set Encoding like utf-8, Not applicable for OLAP connection						
						
						System.out.println("DataCachePurgeFreq  :  "+dbConn.getDataCachePurgeFreq());//defines the time when data cached 
																									//for the selected connection should be deleted and refreshed 
																									//, Not applicable for OLAP connection	
						
						System.out.println("IncrementSize  :  "+dbConn.getIncrementSize());//specifies the number of connections to open when the all open 
																							//connections are consumed.  For example, if 10 connections are presently opened and 
																							//Incremental Size is 3, then when these 10 connections are consumed, 3 more connections will be opened
						
						System.out.println("InitialConnections  :  "+dbConn.getInitialConnections());//Specifies the numkber of initial connection
						
						System.out.println("getMaxConnections  :  "+dbConn.getMaxConnections());//Gives the maximum number of possible connections
						
						System.out.println("MetadataCachePurgeFrequency(  :  "+dbConn.getMetadataCachePurgeFrequency());//defines the time when metadata 
																														//(table names, field names, etc.) cached 
																														//for the selected connection should be deleted and refreshed
																														//, Not applicable for OLAP connection	
						
						System.out.println("Password  :  "+dbConn.getPassword());//Gives the password, Not applicable for OLAP connection	
						System.out.println("ResubmitIdleTime  :  "+dbConn.getResubmitIdleTime());//Specifies the time after which the connection is submitted after being idle.
						System.out.println("StatusMessage  :  "+dbConn.getStatusMessage());//Give the connection Status
						
						System.out.println("TimeZone  :  "+dbConn.getTimeZone());//Give the Time Zone, Not applicable for OLAP connection	
						
						System.out.println("getUserId  :  "+dbConn.getUserId());//Give the user id, Not applicable for OLAP connection	
						
						System.out.println("DbDriver  :  "+dbConn.getDbDriver());//Provide the name of the driver.
						
						//isBlankCredential() :returns true if password is blank and returns false if Password is provided, Not applicable for OLAP connection	
						System.out.println("isBlankCredential  :  "+dbConn.isBlankCredential());
						
						System.out.println("isDefault  :  "+dbConn.isDefault());//Returns true if the connection is a default connection, Not applicable for OLAP connection	
						
						System.out.println("isDefaultOLAP  :  "+dbConn.isDefaultOLAP());//returns true if is a default olap connection
						System.out.println("isReadOnly  :  "+dbConn.isReadOnly());//returns true if the option readonly is checked, Not applicable for OLAP connection	
						System.out.println("isRepository  :  "+dbConn.isRepository());////returns true if  the connection iset as is repository, Not applicable for OLAP connection	
						System.out.println("isTestedConnection  :  "+dbConn.isTestedConnection());//Returns ttrue if the connection is a tested connection
						System.out.println("isUseRuntimeCredential  :  "+dbConn.isUseRuntimeCredential());//Returns true if the runtime option is checked, Not applicable for OLAP connection	
						System.out.println("******************************************************");
						System.out.println("");
						System.out.println("******************************************************");
					}
				}
			}
		}
		catch(LayoutHandlerException lhException)
		{
			lhException.printStackTrace();
		}
		catch(Exception e)
		{
			e.printStackTrace();
		}
	}	
}
