

//This Java API is used to delete the Dashboard Preferences of the requestor user from the Repository.
//This would require user to provide UserInfo i.e. Requestor User's credentials.

//User would require to use following Intellicus jar files for using Intellicus APIs:
//1) intellica.jar
//2) log4ij.jar
//3) xercesImpl.jar
//4) xmlParserAPIs.jar
//Place above jar files in the classpath of your application.
//These jar files are located at  :  <Install_Path>\Intellicus\APIs

/***
 * DISCLAIMER OF WARRANTY
 * This source code is provided "as is" and without warranties as to performance or merchantability. 
 * 
 * This source code is provided without any express or implied warranties whatsoever
 *
**/
 
 
// This program 
// 1) Create a userinfo Object of current logged in User.
// 2) Get DashboardPreferenceId of the Dashboard Preferences for the requesting user
// 3) Using that DashboardPreferenceId, delete the Dashboard Preferences

// Import Section
// Use intellica jar to import these classes
import java.util.ArrayList;
import java.util.Iterator;
import java.io.FileInputStream;
import java.io.BufferedInputStream;
import java.io.InputStream;

import com.intellica.client.common.Enums;
import com.intellica.client.common.Filter;
import com.intellica.client.common.UserInfo;
import com.intellica.client.dashboard.DashboardManager;
import com.intellica.client.dashboard.DashboardPreference;
import com.intellica.client.dashboard.DashboardPreferences;
import com.intellica.client.exception.DashboardException;
import com.intellica.client.init.ReportClient;


//This class is used to delete the Dashboard Preferences of the requestor User.
//The user would require to provide its Credentials.
//The required steps are :  
//1) Create a userInfo Object of the User.
//2) Get the DashboardPreferenceId corresponding to that User's Dashbaord Preferences
//3) Using that DashboardPreferenceId, delete the Dashboard Preferences 
public class DeleteDashboardPreferences {
	public static void main(String args[])
	{
		try
		{
		
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
			InputStream is= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																														//with the absolute path of ReportClient.properties.
			ReportClient.init(is);
			
			// Prepare a requestor user info bean object.
			// This user must have Admin rights to perform user management actions
			// such as create user
			// This user should be present in Intellicus application.
			//Syntax public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
            //@param userId   - : Id of the User Logged-In.
            //@param password - : Password of the User Logged-In.
            //@param orgId    - : Organization Id from which User Logged-In.
			String userId = "John";
			String password = "John";
			String organization = "Intellica";
		    UserInfo requestorUserInfo	=	new UserInfo(userId,password,organization);
			
		    ArrayList dbPreferencesList = null;
		    
			// Create a DashboardManager class object 
			// for Dashboard Management related operations			
		    DashboardManager dManager = new DashboardManager();
		    
			//Filter object to set filer values for OWNERAPPID, OWNERORGID
		    Filter filterObj = new Filter();
		    filterObj.setFilterField(Enums.FilterAttrs.DashBoardPreferences.OWNER_APPID, requestorUserInfo.getUserId());
		    filterObj.setFilterField(Enums.FilterAttrs.DashBoardPreferences.OWNER_ORGID,requestorUserInfo.getOrgID() );
		    
			//get the Dashboard Preference list for that user.
			dbPreferencesList = dManager.getDashBoardPreferences(filterObj, requestorUserInfo);
		    		    		    
			//get the dashboard Preferences object
		   	DashboardPreferences dbPrefs= (DashboardPreferences)dbPreferencesList.get(0);
		   	
			//This method is used to delete the Dashboard Preferences specified by the Dashboard data passed as argument..
		    //@param dashboardPreferenceID The Preference Id corresponding to the Requestor User
		    //@param requestorUserInfo The information about the user for which the Dashboard Preferences are to be deleted. The {@link com.intellica.client.common.UserInfo requestorUserInfo} object for authorization.
		   	dManager.deleteDashBoardPreference(dbPrefs.getDashBoardPreferenceId(), requestorUserInfo);
		   	
			System.out.println("Dashboard Preferences Deleted Successfully--");
		}catch(DashboardException de){
			de.printStackTrace();
		}catch(Exception e)
		{
			e.printStackTrace();
		}
	}
}
