

//This Java API is used to get the complete list of Dashboards from the Intellicus Repository for the Requestor user
//This would require user to provide UserInfo to authorize for Dashboard related operations.
//User would require to use following Intellicus jar files for using Intellicus APIs:
//1) intellica.jar
//2) log4ij.jar
//3) xercesImpl.jar
//4) xmlParserAPIs.jar
//Place above jar files in the classpath of your application.
//These jar files are located at  :  <Install_Path>\Intellicus\APIs

/***
 * DISCLAIMER OF WARRANTY
 * This source code is provided "as is" and without warranties as to performance or merchantability. 
 * 
 * This source code is provided without any express or implied warranties whatsoever
 *
**/
 
 
// This program 
// 1) Create a userinfo Object of current logged in User.
// 2) Get Reports list for a given category from the report server 

// Import Section
// Use intellica jar to import these classes
import java.util.ArrayList;
import java.util.Iterator;
import java.io.FileInputStream;
import java.io.BufferedInputStream;
import java.io.InputStream;

import com.intellica.client.common.Filter;
import com.intellica.client.common.UserInfo;
import com.intellica.client.common.Enums;
import com.intellica.client.dashboard.Dashboard;
import com.intellica.client.dashboard.DashboardManager;
import com.intellica.client.exception.DashboardException;
import com.intellica.client.init.ReportClient;
import com.intellica.client.layout.LayoutManager;


//This class is used to get the list of Dashboards.
//The user would require to provide its credentials.
//The required steps are :  
//1) Create a userInfo Object of the User.
//2) Get dashboard list based on the filter set from the report server
public class GetDashboardList {
	public static void main(String args[])
	{
		try
		{
		
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
			InputStream is= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																														//with the absolute path of ReportClient.properties.
			ReportClient.init(is);
			
			// Prepare a requestor user info bean object.
			// This user must have Admin rights to perform user management actions
			// such as create user
			// This user should be present in Intellicus application.
			//Syntax public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
            //@param userId   - : Id of the User Logged-In.
            //@param password - : Password of the User Logged-In.
            //@param orgId    - : Organization Id from which User Logged-In.
			String userId = "Admin";
			String password = "Admin";
			String organization = "Intellica";
		    UserInfo requestorUserInfo	=	new UserInfo(userId,password,organization);
			
			//This class used for Dashboard related settings.
			//It exposes all the public APIs related to dashboard package
		    DashboardManager dManager = new DashboardManager();
		    ArrayList dashBoardList = new ArrayList();
		    
		    Filter filterObj = new Filter();
		    //To get the Dashboard list
		    filterObj.setFilterField(Enums.Filters.EntityList.ENTITYTYPE,Enums.Filters.EntityList.EntityType.DASHBOARD2);
		    
		    //To get Complete list of Dashboards i.e. present at root and other categories, then set this filter value as COMPLETE.
		    //If set as CURRENT_LEVEL, only Dashboards present at Root are listed and if CategoryId is also given, then Dashboards present in that Category will be listed, but not all.
		    filterObj.setFilterField(Enums.Filters.EntityList.DEPTH,Enums.Filters.EntityList.Depth.COMPLETE);
		    
		    //To get Category list for given Category.
		    filterObj.setFilterField(Enums.Filters.EntityList.CATEGORYID, "cat1");
		    
		    dashBoardList = dManager.getDashboardList(filterObj, requestorUserInfo);
		    
		    Iterator itr = dashBoardList.iterator();
		    while(itr.hasNext()){
		    	Dashboard dashboard = (Dashboard)itr.next();
		    	System.out.println("Dashboard's Category = "+dashboard.getCategoryName());
		    	System.out.println("Dashboard's Name = "+dashboard.getDashBoardId());
		    	System.out.println("Dashboard's Pattern Name = "+dashboard.getPatternName());
		    	System.out.println("Dashboard's Public/Private = "+dashboard.getIsPublic());
		    	System.out.println();
		    }
		 
		}catch(DashboardException de)
		{
			de.printStackTrace();
		}catch(Exception e)
		{
			e.printStackTrace();
		}
	}
}
