
//This Java API is used to get the list of the Dashboards set in its Preferences.
//This would require user to provide its login credentials for authorization purpose as well as for getting preferences for the requestor user.

//User would require to use following Intellicus jar files for using Intellicus APIs:
//1) intellica.jar
//2) log4ij.jar
//3) xercesImpl.jar
//4) xmlParserAPIs.jar
//Place above jar files in the classpath of your application.
//These jar files are located at  :  <Install_Path>\Intellicus\APIs

/***
 * DISCLAIMER OF WARRANTY
 * This source code is provided "as is" and without warranties as to performance or merchantability. 
 * 
 * This source code is provided without any express or implied warranties whatsoever
 *
**/
 
 
// This program 
// 1) Create a userinfo Object of current logged in User.
// 2) Get Dashboard Preferences list for the requestor User.

// Import Section
// Use intellica jar to import these classes
import java.util.ArrayList;
import java.util.Iterator;
import java.io.FileInputStream;
import java.io.BufferedInputStream;
import java.io.InputStream;

import com.intellica.client.common.Enums;
import com.intellica.client.common.Filter;
import com.intellica.client.common.UserInfo;
import com.intellica.client.dashboard.Dashboard;
import com.intellica.client.dashboard.DashboardManager;
import com.intellica.client.dashboard.DashboardPreference;
import com.intellica.client.dashboard.DashboardPreferences;
import com.intellica.client.exception.DashboardException;
import com.intellica.client.init.ReportClient;
import com.intellica.client.personalization.DashBoard;
import com.intellica.client.personalization.DashBoardPreferences;

//This class is used to get the Dashboard Preference List of the requestor User from the Report Server.
//The user would require to provide its User Credentials. 
//The required steps are :  
//1) Create a userInfo Object of the User.
//2) Get Dashboard list present in its Preferences.
public class GetDashboardPreferences {
	public static void main(String args[])
	{
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
			InputStream is= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																														//with the absolute path of ReportClient.properties.
			ReportClient.init(is);
			
			// Prepare a requestor user info bean object.
			// This user must have Admin rights to perform user management actions
			// such as create user
			// This user should be present in Intellicus application.
			//Syntax public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
            //@param userId   - : Id of the User Logged-In.
            //@param password - : Password of the User Logged-In.
            //@param orgId    - : Organization Id from which User Logged-In.
			String userId = "Normal";
			String password = "";
			String organization = "Intellica";
		    UserInfo requestorUserInfo	=	new UserInfo(userId,password,organization);
			
		    ArrayList dbPreferencesList = null;

			// Create a DashboardManager class object 
			// for Dashboard Management related operations			
		    DashboardManager dManager = new DashboardManager();
		    
		    Filter filterObj = new Filter();
		    filterObj.setFilterField(Enums.FilterAttrs.DashBoardPreferences.OWNER_APPID, requestorUserInfo.getUserId());
		    filterObj.setFilterField(Enums.FilterAttrs.DashBoardPreferences.OWNER_ORGID,requestorUserInfo.getOrgID() );
		    //Getting Dashboard Preferences Object
			dbPreferencesList = dManager.getDashBoardPreferences(filterObj, requestorUserInfo);
		    		    		    
		   	DashboardPreferences dbPrefs= (DashboardPreferences)dbPreferencesList.get(0);
		   
		   	ArrayList dbList = null;
			//Getting list of Dashboards present in Preferences
		   	dbList = dbPrefs.getDashBoardPreferenceList();
		   	
			//Iterating through the Preference list
		   	Iterator itr = dbList.iterator();
		   	while(itr.hasNext()){
		   		DashboardPreference dashboard = (DashboardPreference)itr.next();
		    	System.out.println("Dashboard Id - "+dashboard.getDashBoardId());
		    	System.out.println("Dashboard Name - "+dashboard.getDashBoardPatternName());
		    	System.out.println("Dashboard Preference Sequesnce No - "+dashboard.getSequenceNumber());
		    	System.out.println();
		    }
	    
		}catch(DashboardException de)
		{
			de.printStackTrace();
		}catch(Exception e)
		{
			e.printStackTrace();
		}
	}
}
