
//This Java API is used to get the widgets present in given Category from the Intellicus Repository.
//This would require User to provide the Category ID.
//This would require user to provide User credentials to authorize for Dashboard widget related operations.

//User would require to use following Intellicus jar files for using Intellicus APIs:
//1) intellica.jar
//2) log4ij.jar
//3) xercesImpl.jar
//4) xmlParserAPIs.jar
//Place above jar files in the classpath of your application.
//These jar files are located at  :  <Install_Path>\Intellicus\APIs

/***
 * DISCLAIMER OF WARRANTY
 * This source code is provided "as is" and without warranties as to performance or merchantability. 
 * 
 * This source code is provided without any express or implied warranties whatsoever
 *
**/
 
 
// This program 
// 1) Create a userinfo Object of current logged in User.
// 2) Get Dashboard widget list for a given category from the report server.

// Import Section
// Use intellica jar to import these classes
import java.util.ArrayList;
import java.util.Iterator;
import java.io.FileInputStream;
import java.io.BufferedInputStream;
import java.io.InputStream;

import com.intellica.client.common.Enums;
import com.intellica.client.common.Filter;
import com.intellica.client.common.UserInfo;
import com.intellica.client.dashboard.DashboardManager;
import com.intellica.client.dashboard.DashboardWidget;
import com.intellica.client.exception.DashboardException;
import com.intellica.client.init.ReportClient;

//This class is used to get the list of Dashboard widgets present in given Category from the Report Server.
//The user would require to provide the Category ID and its identity i.e UserInfo. 
//The required steps are :  
//1) Create a userInfo Object of the User.
//2) Provide the Category ID whose Dashboard widgets are to be listed
//3) Get the require widget list from the report server
public class GetDashboardWidgetsForCategory {
	public static void main(String args[])
	{
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
			InputStream is= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																														//with the absolute path of ReportClient.properties.
			ReportClient.init(is);
			
			// Prepare a requestor user info bean object.
			// This user must have Admin rights to perform user management actions
			// such as create user
			// This user should be present in Intellicus application.
			//Syntax public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
            //@param userId   - : Id of the User Logged-In.
            //@param password - : Password of the User Logged-In.
            //@param orgId    - : Organization Id from which User Logged-In.
			String userId = "Admin";
			String password = "Admin";
			String organization = "Intellica";
		    UserInfo requestorUserInfo	=	new UserInfo(userId,password,organization);
			
			// Create a DashboardManager class object 
			// for Dashboard Management related operations			
		    DashboardManager dManager = new DashboardManager();
		    ArrayList dashBoardWidgetList = new ArrayList();
		    
			//Provide the Category Id whose Dashboard list is to be obtained
			String categoryId = "6D018637-ABA1-EDBC-7578-3857C79AC427";
		    
		    Filter filterObj = new Filter();
		    //To get the Dashboard list
		    filterObj.setFilterField(Enums.Filters.EntityList.ENTITYTYPE,Enums.Filters.EntityList.EntityType.DASHBOARD_WIDGET);
		    
		    //To get Widget list for given Category.
		    filterObj.setFilterField(Enums.Filters.EntityList.CATEGORYID, categoryId);
		    //Traversal
		    filterObj.setFilterField(Enums.Filters.EntityList.TRAVERSAL,Enums.Filters.EntityList.Traversal.DOWN);
		    //Getting the Dashboard widget list based on filters sent
		    dashBoardWidgetList = dManager.getDashboardWidgetList(filterObj, requestorUserInfo);
		    
			//Iterating through the widget list
		    Iterator itr = dashBoardWidgetList.iterator();
		    System.out.println("Widget List in Category - "+categoryId);		    
			while(itr.hasNext()){
		    	DashboardWidget dashboardWidget = (DashboardWidget)itr.next();
		    	System.out.println("Dashboard Widget Name = "+dashboardWidget.getName());
		    	System.out.println("Dashboard Widget Type = "+dashboardWidget.getWidgetType());
		    	System.out.println();
		    }
		}catch(DashboardException de)
		{
			de.printStackTrace();
		}catch(Exception e)
		{
			e.printStackTrace();
		}
	}
}
