//This Java API is used to add a report to an existing Category in the Intellicus repository. 
//This would require User to provide the Category ID, and the details related to the Report
//i.e to be added.
//It would also require User Info to authorize for publish layout rights.

//User would require to use following Intellicus jar files for using Intellicus APIs:
//1) intellica.jar
//2) log4ij.jar
//3) xercesImpl.jar
//4) xmlParserAPIs.jar
//Place above jar files in the classpath of your application.
//These jar files are located at  :  <Install_Path>\Intellicus\APIs

/***
 * DISCLAIMER OF WARRANTY
 * This source code is provided "as is" and without warranties as to performance or merchantability. 
 * 
 * This source code is provided without any express or implied warranties whatsoever
 *
**/

// Import Section
// Use intellica jar to import these classes
import com.intellica.client.common.UserInfo; //For getting user information
import com.intellica.client.exception.InterfaceInitException;//Thrown as and when there is any error
                                                             //in initializing the report Engine interface (REInterface). 
import com.intellica.client.exception.LayoutHandlerException;
import com.intellica.client.init.ReportClient;// Has Init Method
import com.intellica.client.layout.LayoutManager;// for report layout management related operations			
import com.intellica.client.reportutils.Report;//Class contains the details of the irl file. 

import java.io.File;
import java.io.FileInputStream;// for reading file from the disk.
import java.io.BufferedInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;//For the input/output Exceptions.
import java.io.InputStream;//represents an input stream of bytes.


//This class is used to add a report to an existing Category in the Report Server
//The steps followed are :
//1) Create a userinfo Object of current logged in User.
//2) Get the File from the specific location that needs to be added to the Category
//	 and create a report with same contents
//3) Add the so created Report to the existing Category
public class AddReportLayoutToCategory 
{
	public static void main(String args[])
	{
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
			InputStream in= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																														//with the absolute path of ReportClient.properties.
			ReportClient.init(in);
			
			// Prepare a requestor user info bean object.
			// This user should be present in Intellicus application.
			//Syntax : public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
            //@param userId   - : Id of the User Logged-In.
            //@param password - : Password of the User Logged-In.
            //@param orgId    - : Organization Id from which User Logged-In.
			String	userId	=	"Admin";
			String password = "Admin";
			String organization = "Intellica";
			UserInfo requestorUserInfo	=	new UserInfo(userId,password,organization);
			
			//Create a Layout Manager class object 
			// for report layout management related operations			
			LayoutManager lm= new LayoutManager();
			
		
			String f= "C:/DemoSalesReview.irl";
			File file = new File(f);
			
			//Read the contents from the given file
			InputStream is = new FileInputStream(file);
			
			// Get the size of the file
	        long length = file.length();
	        System.out.println(length);
	        // User cannot create an array using a long type.
	        // It needs to be an int type.
	        // Before converting to an int type, check
	        // to ensure that file is not larger than Integer.MAX_VALUE.
	        if (length > Integer.MAX_VALUE) {
	            // File is too large
	        	throw new Exception("File is too Large");
	        }
	        
	        else {
	        	// Create the byte array to hold the data
				byte[] bytes = new byte[(int) length];
				// Read in the bytes
				int offset = 0;
				int numRead = 0;
				while (offset < bytes.length
						&& (numRead = is.read(bytes, offset, bytes.length
								- offset)) >= 0) {
					offset += numRead;
				}
				//	Ensure all the bytes have been read in
				if (offset < bytes.length) {
					throw new IOException("Could not completely read the file ");
				}
				// Close the input stream and return bytes
				is.close();
				String reportName = "DemoSalesReview";
				String reportID = "DemoSalesReview";
				//Pass the Report Menu Name,category Id, and byte[] of IRL File.
				//The constructor to initiate a Report object.
				//Syntax : public Report(java.lang.String strReportMenuName,java.lang.String strCategoryId,
				//															byte[] IRLData)
				//@param strReportMenuName - string containing the reports menu name
				//@param strCategoryId - CategoryId of report
				//@param IRLData - byte array of irl data of report
				System.out.print(new String(bytes));
				//Category ID in which report is to be added
				String categoryID = "BDD4CEB6-2B71-B681-A32B-8E87DA9BD10E";

				Report reportToAdd = new Report(reportID, bytes, categoryID);
				
				//Add the Report to the Category with given Category ID
				//This method sets the category Id 
				//Syntax : public void setCategoryId(java.lang.String strCategoryId)
				//@param strCategoryId - value of the category Id.
				reportToAdd.setReportName(reportName);
				//Uploads a report by taking the Report object as parameter. 
				//This method internally validates the Report object for report paramaters. 
				//The method also verifies if report already exists in the specified category. 
				//In case report object is not validated and verified the method throws LayoutHandlerException exception.
				//The calling code must catch the exception right at the calling place.
				//Syntax : public void uploadReport(Report report, UserInfo userInfo)
				//@param report - Report class instance containing the report layout metadata and the byte array of report layout itself.
				//@param requestorUserInfo - UserInfo object use to validate the user against the application. 
				lm.uploadReport(reportToAdd, requestorUserInfo);
			}	        
		}
		catch(InterfaceInitException iie)
		{
		System.out.println ("Could not connect to report server::"+iie.getErrorMessage());
		//	iie.printStackTrace();
		}
		catch(FileNotFoundException fe)
		{
			System.out.println("File Not Found");
		}
		catch(IOException ie)
		{
			System.out.println("I/O operations failed or interrupted");
		}
		catch(LayoutHandlerException lhe)
		{
			System.out.println("Unable to upload report");
		}
		catch(Exception e)
		{
			e.printStackTrace();
		}
	}
}
