//This Java API is used to copy an existing report to another Destination Category.
//This would require user to provide UserInfo to authorize for performing Reports related activities.
//User need to provide the ReportID that is to be copied and the Destination Category ID where it is to be Copied.

//User would require to use following Intellicus jar files for using Intellicus APIs:
//1) intellica.jar
//2) log4ij.jar
//3) xercesImpl.jar
//4) xmlParserAPIs.jar
//Place above jar files in the classpath of your application.
//These jar files are located at  :  <Install_Path>\Intellicus\APIs

/***
 * DISCLAIMER OF WARRANTY
 * This source code is provided "as is" and without warranties as to performance or merchantability. 
 * 
 * This source code is provided without any express or implied warranties whatsoever
 *
**/


import com.intellica.client.common.UserInfo; // Object used to pass in run report
import com.intellica.client.exception.InterfaceInitException;//Thrown as and when there is any error
                                                             //in initializing the report Engine interface (REInterface). 
import com.intellica.client.exception.LayoutHandlerException;//This Exception class is used for all Layout use cases.
import com.intellica.client.init.ReportClient;// Has Init Method
import com.intellica.client.layout.LayoutManager;// for report layout management related operations			
import com.intellica.client.reportutils.Report;//Class contains the details of the irl file. 

import java.io.FileInputStream;
import java.io.BufferedInputStream;
import java.io.InputStream;
/**
 * 
 * This class is used to make a copy of the existing report attributes to another destination Category with 
 * given Category ID 
 */
public class CopyReport 
{
	public static void main(String arg[])
	{
		
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
			InputStream is= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																														//with the absolute path of ReportClient.properties.
			ReportClient.init(is);
			
			// Prepare a requestor user info bean object.
			// This user should be present in Intellicus application.
			// Syntax : public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
            // @param userId   - : Id of the User Logged-In.
            // @param password - : Password of the User Logged-In.
            // @param orgId    - : Organization Id from which User Logged-In.
			String	userId	=	"Admin";
			String password = "Admin";
			String organization = "Intellica";
			UserInfo requestorUserInfo	=	new UserInfo(userId,password,organization);
						
			// Report class contains the details of the irl file. 
			// This is the default constructor to create report object.
			Report r=new Report();
			
			// If want to Assign name to the copied report in the destination Category.
		    // If not Given , then by default it takes the same name as that in the Source Category.
			r.setMenuName("Copied_Report");  
			
						
			// Create a Layout Manager class object 
			// for report layout management related operations			
			LayoutManager lm= new LayoutManager();
			
			//ReportId that is to be Copied
			String sourceReportId = "Application_Summary_Report";
			
			//Category ID of the Destination Category where the Report is to be Copied.
			String destCategoryId = "DataLoader";
			
			// Method to copy the report to anther Category
			// @param 1 : sourceReportId - source report id that is to be copied,mandatory argument for copying the report.
			// @param 2 : destinationCategoryId - destination category id,where new report has to be copied.if this is null then source report's category id will be taken as destination category.
			// @param 3 : report - instance of Report class for copy.
			// @param 4 : requestorUserInfo - UserInfo object for authorization. 
			lm.copyReport(sourceReportId, destCategoryId, r, requestorUserInfo);
			
		}
		catch(InterfaceInitException iie)
		{
		System.out.println ("Could not connect to report server::"+iie.getErrorMessage());
		//	iie.printStackTrace();
		}
		catch(LayoutHandlerException lhe)
		{
			System.out.println("Unable to copy report");
		}
		catch(Exception e)
		{
			e.printStackTrace();
		}
	}	
}		
		
		
		
		
		
		
		
	
    
	

