// This program 
// 1) Copies the Source Report(Given Source ReportId) in the given existing Destination Category.
// 2) Create a new Query Object same as that of the Source Report just differing in its name.
// 3) Grant Organization specific Access Rights to the newly created Query Object.
// 4) Update the Copied Report by modifying the Query Object of Copied Report which is newly created.

//User would require to use following Intellicus jar files for using Intellicus APIs:
//1) intellica.jar
//2) log4ij.jar
//3) xercesImpl.jar
//4) xmlParserAPIs.jar
//Place above jar files in the classpath of your application.
//These jar files are located at  :  <Install_Path>\Intellicus\APIs

/***
 * DISCLAIMER OF WARRANTY
 * This source code is provided "as is" and without warranties as to performance or merchantability. 
 * 
 * This source code is provided without any express or implied warranties whatsoever
 *
 **/


// Import Section
import java.io.FileInputStream;
import java.io.BufferedInputStream;
import java.io.InputStream;

// Use intellica jar to import these classes
import java.io.ByteArrayInputStream; //A ByteArrayInputStream contains an internal buffer that contains bytes that may be read from the stream.
import com.impetus.intera.layout.adhoc.AdhocLayoutManager;  //This Class is responsible for managing following type of request
															//Fetching Saved Adhoc Report layout for given report id
															//Fetching configuration information from its property file
import com.impetus.intera.layout.adhoc.AdhocReportLayout; //It holds informatiom about DataSource,Template,Filters,Groups,Charts,
import com.impetus.intera.layout.sqleditor.SQLEditor;//This class contains properties and parsing logic for the SQLEDITOR of the report.
import com.impetus.intera.reportobjects.QueryObject;// This class contains all the details about the query object.
import com.impetus.intera.reportobjects.ReportObject;//This class is super class of all the report objects
import com.impetus.intera.reportobjects.ReportObjectException;
import com.impetus.intera.reportobjects.ReportObjectManager;//This class is used for Report Object related operations.
import com.intellica.client.common.Enums;// Has Enums for the constants used
import com.intellica.client.common.UserInfo; // user info bean
import com.intellica.client.exception.ISecurityException;// For exceptions during user management
import com.intellica.client.exception.InterfaceInitException;//Thrown as and when there is any error
															//in initializing the report Engine interface (REInterface). 
import com.intellica.client.exception.LayoutHandlerException;
import com.intellica.client.init.ReportClient;// Has Init Method
import com.intellica.client.layout.LayoutManager;// for report layout management related operations
import com.intellica.client.reportutils.Report;//Class contains the details of the irl file.
import com.intellica.client.security.EntityAccessRight;//has Entity Access Rights mechanism
import com.intellica.client.security.EntityInfo;//For assigning to Organization
import com.intellica.client.utils.Utility;// has getGUID(), used to auto-generate ReportId.
import com.intellica.client.security.SecurityManager;// Has user management methods
import com.intellica.client.security.AppInfo;//for creating AppInfo instance

/*
 * This class copies a Report into destination Category and then modifies its Data source. 
 */
public class CopyReportWithModifiedQO {

	
	public static void main(String args[])
	{
		try{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
			InputStream is= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																														//with the absolute path of ReportClient.properties.
			ReportClient.init(is);
			
			// Prepare a requestor user info bean object.
			// This user must have Admin rights to perform user management actions
			// such as create user
			// This user should be present in Intellicus application.
			//Syntax public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
            //@param userId   - : Id of the User Logged-In.
            //@param password - : Password of the User Logged-In.
            //@param orgId    - : Organization Id from which User Logged-In.
			String	userId	=	"Admin";
			String password = "Admin";
			String organization = "Intellica";
			UserInfo userInfo =	new UserInfo(userId,password,organization);

			//Report Id of the report that is to be copied.
			String reportID = "3BB5860F-D74D-684C-767A-48F1B8F9D29D";
			//Destination Category wahere the report is to be copied.
			String destinationCat = "2AA1BADF-F9C2-EAB9-5E2F-497DE7A10B4D";
			
			//copyRptToDomain(String reportName, String srcReportId, String domain, UserInfo userInfo)
			//@param reportName : Report Name of the Report i.e. to be copied in the destination Category
			//@param srcReportId : Report Id of the report that is to be copied.
			//@param domain : Destination Category wahere the report is to be copied.
			//@param userInfo : UserInfo of the Requestor User.
			copyRptToDomain("copiedReport",reportID,destinationCat, userInfo);
			}catch(Exception e)
			{
				e.printStackTrace();
			}
		}
    //Method used to perform copy Report Operation and update the report by changing its Data Source.
	private static Report copyRptToDomain(String reportName, String srcReportId, String domain, UserInfo userInfo)
    {
    	//Local object of Report containing attributes of copied Report
        Report copiedReport = null;
		
        //Create a Layout Manager class object 
		// for report layout management related operations			
        LayoutManager lm = new LayoutManager();
        
		//This class contains method to get/replace/add/delete a Query object(QO)
        ReportObjectManager rom = new ReportObjectManager();
        
        //Object of Source Report that is to be copied.
        Report srcRpt = null;
        
        //Objet of new Copied Report 
        Report newReport = null;
        
        //Object of QueryObject i.e bound to the Source Report.
        QueryObject srcQO = null;
        
        //Object of QueryObject i.e modified for the Copied Report.
        QueryObject newQO = null;
        
        //Report Id of the copied Report
        String destReportId = null;
        
        //It holds informatiom about DataSource,Template,Filters,Groups,Charts,
        //Matrix,Sumarries,Sort-orders used for desiging this Adhoc Report.
        AdhocReportLayout adhocReportLayout = new AdhocReportLayout();
        
        //This Class is responsible for managing following type of request
        //Fetching Saved Adhoc Report layout for given report id
        //Fetching configuration information from its property file
        AdhocLayoutManager adhocManager = null;
        
        try {
        	//System Generated Reporrt Id through getGUID() for destination Report 
            destReportId = Utility.getGUID();
            
            /***** Code to get the QO of the Source Report *************/
            
            //Get the IRL Bytes of the Source Report.
            byte reportIRL[]=lm.getIRLFile(srcReportId,userInfo);

            //Parse the xml of IRL Bytes 
		   	adhocReportLayout.parseXml(new ByteArrayInputStream(reportIRL));
		   	
		   	//Get the Data Source(QO) of the Report through parsed xml. 
		   	String srcQOId = adhocReportLayout.getDataSource().getId();
		   	
		   	//Getting object of Query Object of Source Report.
		   	srcQO =(QueryObject)rom.getReportObject(Enums.IRO.TYPE.QUERY, srcQOId, userInfo);
		   	srcRpt = lm.getReportDetails(srcReportId, userInfo);
            /****************************************************************/
		   	
		   	/******* Creating a new Query and adding itinto Repository ***********************************/
            //Creating new Query Object for copied Report and setting its attributes
            newQO = (QueryObject)ReportObject.createReportObject(Enums.IRO.TYPE.QUERY);
            newQO.setId(Utility.getGUID());
            newQO.setName(srcQO.getName() + "_" + domain);
            newQO.setSource("SQL");
            newQO.setConnectionType(srcQO.getConnectionType());
            newQO.setConnectionName(srcQO.getConnectionName());
            SQLEditor sqlEditor = newQO.getSqlEditor();
            newQO.setColumnDetails(srcQO.getColumnDetails());
            sqlEditor.setSQL(srcQO.getSqlEditor().getSQL(), true);
            newQO.setName(srcQO.getName() + "_" + domain);	

            //Add the Report Object in the Repository
            rom.addReportObject(newQO, userInfo);
           /****************************************************************/
            
            /********** Assigning Access Rights to Query Object **************/
            //Assigning Organization based Access Rights to the Query Object 
            EntityAccessRight ear = new EntityAccessRight();
            ear.setAccessLevel(1);//1 : Gives rights to Everyone, 0 : No-one
            
            //AppInfo(java.lang.String appId, java.lang.String orgId) 
            //constructor for creating AppInfo instance.
            //Assigning to a particular Organization
            //@param appId : Application Type. Leave it blank for all the Users and Roles of the Organization
            //@param orgId : Organization Id whose access rights are to be set.
            AppInfo ai = new AppInfo("", domain);
            ear.setAppInfo(ai);
            
            //Set the access rights for Querry Object
            EntityInfo ei = new EntityInfo(newQO.getId(), "QO");
            
			// Create a SecurityManager class object 
		    // for getting the controller information for all Administration related operations
			//public getInstance method to access the static instance of SecurityManager object
			//Syntax public static SecurityManager getInstance()
            SecurityManager sManager = SecurityManager.getInstance();
            
            //This API allows the user to assign access rights information to 
            //a user/role/organization or Everyone on an entity. 
            sManager.grantEntityPrivileges(ei, ear, userInfo);
            /****************************************************************/
            
            /****** Copying the Source Report to Destination Category *******/
            //Setting the attributes for copied Report 
            copiedReport = new Report();
            copiedReport.setMenuName(srcRpt.getMenuName());
            copiedReport.setDesignMode("ADHOC");
            copiedReport.setIsPublic(true);
            copiedReport.setIsHidden(false);
            copiedReport.setReportId(destReportId);
            copiedReport.setDBConnection(srcRpt.getDBConnection());
            copiedReport.setOwnerOrgId(domain);
            lm = new LayoutManager();
            
            //Method to make a copy of the existing report attributes. 
            //Syntax : public void copyReport(java.lang.String sourceReportId,java.lang.String destinationCategoryId,Report report,UserInfo userInfo)
            //@param sourceReportId - source report id,mandatory argument for copying the report.
            //@param destinationCategoryId - destination category id,where new report has to be copied.if this is null then source report's category id will be taken as destination category.
            //@param report - instance of Report class for copy.
            //@param userInfo - UserInfo object for authorization. 
            lm.copyReport(srcReportId, domain, copiedReport, userInfo);
            /****************************************************************/
             
            /********** Updating Copied Report by changing Data Source ******/ 
            adhocManager = new AdhocLayoutManager();
            adhocReportLayout = adhocManager.getAdhocReport(destReportId, userInfo);
 
            //Set the data source of the adhoc Report Layout 
            adhocReportLayout.getDataSource().setId(newQO.getId());
            adhocReportLayout.getDataSource().setName(newQO.getName());
           
            //Setting the attributes of newly copied Report i.e Report Id and IRL Bytes containing newly 
            newReport = new Report();
            newReport.setReportId(destReportId);
            newReport.setIRLBytes((adhocReportLayout.getXml()).getBytes());
            
            // Method to modify/update the report object for it's menu name and IRL file content.
            lm.updateReport(copiedReport, newReport, userInfo);
            /*****************************************************************/
        }
		catch(InterfaceInitException iie)
		{
		System.out.println ("Could not connect to report server::"+iie.getErrorMessage());
		//	iie.printStackTrace();
		}
        catch (LayoutHandlerException e) {
        	e.printStackTrace();
            System.out.println("LayoutHandlerException: Failed copying report [" + reportName + "] to domain[" + domain + "]");
            try {
                rom.deleteReportObject(newQO, userInfo);
            } catch (ReportObjectException roe) {
                System.out.println("ReportObjectException: Failed deleting QO [" + newQO.getName() + "] to domain[" + domain + "]");
            }
            copiedReport = null;
        } catch (ISecurityException ise) {
            ise.printStackTrace();
        }
        catch (Exception e) {
        	e.printStackTrace();
            System.out.println("Exception: Failed copying report [" + reportName + "] to domain[" + domain + "]");
            try {
                rom.deleteReportObject(newQO, userInfo);
            } catch (ReportObjectException roe) {
                System.out.println("ReportObjectException: Failed deleting QO [" + newQO.getName() + "] to domain[" + domain + "]");
            }
            copiedReport = null;
        }
        return copiedReport;
    }

	
}
