//This Java API is used to get the complete list of the Reports in a particular Category 
//from the Intellicus Repository.
//This would require User to provide the Category ID whose reports are to be listed and the
//This would require user to provide UserInfo to authorize for View Reports layout rights.

//User would require to use following Intellicus jar files for using Intellicus APIs:
//1) intellica.jar
//2) log4ij.jar
//3) xercesImpl.jar
//4) xmlParserAPIs.jar
//Place above jar files in the classpath of your application.
//These jar files are located at  :  <Install_Path>\Intellicus\APIs

/***
 * DISCLAIMER OF WARRANTY
 * This source code is provided "as is" and without warranties as to performance or merchantability. 
 * 
 * This source code is provided without any express or implied warranties whatsoever
 *
**/
 
 
// This program 
// 1) Create a userinfo Object of current logged in User.
// 2) Get Reports list for a given category from the report server 

// Import Section
// Use intellica jar to import these classes
import com.intellica.client.init.ReportClient; // Has Init Method
import com.intellica.client.common.UserInfo; // Object used to pass in run report
import com.intellica.client.layout.LayoutManager;// for report layout management related operations			
import com.intellica.client.reportutils.Report;//Class contains the details of the irl file. 
import com.intellica.client.exception.InterfaceInitException;//Thrown as and when there is any error
                                                             //in initializing the report Engine interface (REInterface). 
import com.intellica.client.exception.LayoutHandlerException;//This Exception class is used for all Layout use cases.

import java.util.Vector;
import java.io.FileInputStream;
import java.io.BufferedInputStream;
import java.io.InputStream;

//This class is used to get the complete list of the Reports in a particular Category from the Report Server.
//The user would require to provide the Category ID and its identity i.e UserInfo. 
//The required steps are :  
//1) Create a userInfo Object of the User.
//2) Provide the Category ID whose Reports are to be listed
//3) Get all reports from the report server
public class GetReportListForCategory
{
	public static void main(String args[])
	{
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
			InputStream is= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																														//with the absolute path of ReportClient.properties.
			ReportClient.init(is);
			
			// Prepare a requestor user info bean object.
			// This user should be present in Intellicus application.
			//Syntax : public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
            //@param userId   - : Id of the User Logged-In.
            //@param password - : Password of the User Logged-In.
            //@param orgId    - : Organization Id from which User Logged-In.
			String	userId	=	"Admin";
			String password = "Admin";
			String organization = "Intellica";
			UserInfo requestorUserInfo	=	new UserInfo(userId,password,organization);
			
			//com.intellica.client.layout.LayoutManager class is responsible for managing 
			//all report layout operations. The methods of this class are stateless and 
			//takes all required information such as requestor User Info etc. in each call.		
			LayoutManager lm= new LayoutManager();
			
			//Category ID of the Category whose Reports are required to be Listed 
			String catId = "24719DA0-7912-5D25-2C2F-27B1FBFF8FB8"; 
						
			//Vector that will be used to store the Report List
			Vector vecReportList= new Vector();
		
			try
			{
				// This method returns a vector of Report objects. 
				//The method requests report server and returns the reports present in the 
				//report repository under given report category, both public and private to 
				//requestor user. 
				//The public reports will be restricted to those reports that the requestorUserInfo has access to read. Each report object provides getIsPublic boolean method to identify the scope of report.for the Category of given catId.
				//Syntax : public java.util.Vector getReportListForCategory(java.lang.String categoryId,
				//													UserInfo requestorUserInfo)
				//@param categoryId - -The category Id of the category from which, the report layout list is requested. Intellicus allows category ids upto 256 charecters long.
				//@param requestorUserInfo - UserInfo for authorization. Pass getEmptyInstance() in case of report server runs in Security-Off mode. 
				vecReportList=lm.getReportListForCategory(catId,requestorUserInfo);
			}
			catch(LayoutHandlerException lhe)
			{
				//If Category does not exist
				System.out.println ("Category: "+catId+" does not exist");	
			}
		
			// When vector of report list is not empty
			if(vecReportList!=null)
			{
				//Iterating through the complete Vector list to get each Report's Details.
				for (int i = 0;i< vecReportList.size(); i++)
				{
				
					// This will return Report Object
					Report report = (Report)vecReportList.get(i);
					
					//Calling various methods of Report class to get various details.
					String reportId = report.getReportId();
					String reportName = report.getReportName();
					System.out.println ();
					System.out.println ("ReportName:"+reportName);
					System.out.println ("ReportId:"+reportId);
					System.out.println ("CategoryId:"+report.getCategoryId());
					System.out.println ("CategoryMenuName:"+report.getCategoryMenuName());
					System.out.println ("DBConnection:"+report.getDBConnection());
					System.out.println ("DeploymentRptType:"+report.getDeploymentRptType());
					System.out.println ("Description:"+report.getDescription());
					System.out.println ("DesignMode:"+report.getDesignMode());
					System.out.println ("IsPublic:"+report.getIsPublic());
					System.out.println ("OwnerAppId:"+report.getOwnerAppId());
					System.out.println ("OwnerOrgId:"+report.getOwnerOrgId());
					System.out.println ("getPriority:"+report.getPriority());
					System.out.println ("getReportAccessRight:"+report.getReportAccessRight());
					System.out.println ("ReportFormat:"+report.getReportFormat());
					System.out.println ("OwnerOrgId:"+report.getOwnerOrgId());
					System.out.println ("MenuName:"+report.getMenuName());
					System.out.println ("Version:"+report.getVersion());
					System.out.println ("VersionDate:"+report.getVersionDate());
			
				}//(end for loop)																					
		}//end if 
							
		}
		catch(InterfaceInitException iie)
		{
		System.out.println ("Could not connect to report server::"+iie.getErrorMessage());
		//	iie.printStackTrace();
		}
		catch(Exception e)
		{
			e.printStackTrace();
		}
	}
}		
