//This Java API is used to get the list of Saved Reports in a particular Category/Report 
//from the Intellicus Repository.
//This would require User to provide the Category ID whose reports are to be listed and the
//This would require user to provide UserInfo to authorize for View Reports layout rights.

//User would require to use following Intellicus jar files for using Intellicus APIs:
//1) intellica.jar
//2) log4ij.jar
//3) xercesImpl.jar
//4) xmlParserAPIs.jar
//Place above jar files in the classpath of your application.
//These jar files are located at  :  <Install_Path>\Intellicus\APIs

/***
 * DISCLAIMER OF WARRANTY
 * This source code is provided "as is" and without warranties as to performance or merchantability. 
 * 
 * This source code is provided without any express or implied warranties whatsoever
 *
**/
// Import Section
import java.io.BufferedInputStream;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.Vector;

//Use intellica jar to import these classes
import com.intellica.client.common.Filter;
import com.intellica.client.common.UserInfo;
import com.intellica.client.exception.InterfaceInitException;
import com.intellica.client.exception.LayoutHandlerException;
import com.intellica.client.init.ReportClient;// Has Init Method
import com.intellica.client.layout.LayoutManager;// for report layout management related operations			
import com.intellica.client.reportutils.SavedReport;//For Save Report

//This class is to get the list of saved reports.
public class GetSavedReportList {
public static void main(String args[]){
	try	{
		
		// Static Init call. it will read the properties for report server related attributes 
		// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
		//in the INTERA_HOME property of the ReportClient.properties file.
		InputStream is= new BufferedInputStream(new FileInputStream("C:\\Program Files\\Intellicus\\Jakarta\\webapps\\intellicus\\client\\config\\ReportClient.properties"));//Replace by <ReportClient.properties_Absolute Path> 
																													//with the absolute path of ReportClient.properties.
		ReportClient.init(is);
//		 Prepare a requestor user info bean object.
		// This user should be present in Intellicus application.
		//Syntax : public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
        //@param userId   - : Id of the User Logged-In.
        //@param password - : Password of the User Logged-In.
        //@param orgId    - : Organization Id from which User Logged-In.
		String	userId	=	"Admin";
		String password = "Admin";
		String organization = "Intellica";
		UserInfo requestorUserInfo	=	new UserInfo(userId,password,organization);
		//com.intellica.client.layout.LayoutManager class is responsible for managing 
		//all report layout operations. The methods of this class are stateless and 
		//takes all required information such as requestor User Info etc. in each call.		
		LayoutManager lm= new LayoutManager();
		
		//Category ID of the Category whose Reports are required to be Listed 
		String catId = "4F9245A7-D639-4F99-604D-F32641B77725"; //category id to be set in filter
		String reportId="All Country Sales - Linked Prompt";//Report Id to be set in filter
					
		//Vector that will be used to store the Report List
		Vector vecSavedReportList= new Vector();
		try
		{
			Filter filter = new Filter();
			filter.setFilterField(com.intellica.client.common.Enums.Filters.SavedReportList.CATID, catId);
			filter.setFilterField(com.intellica.client.common.Enums.Filters.SavedReportList.REPORTID, reportId);
			/**
			 * The following method returns a vector of {@link com.intellica.client.reportutils.SavedReport SavedReport} objects.
			 * The method requests report server and returns a list of saved reports
			 * present in the report repository for the given report ID.
			 * The list of saved reports will be restricted to those reports that the
			 * requestorUserInfo has access to read.
			 *
			 * @param filter Filter The filters to be applied for the request. See {@link com.intellica.client.common.Enums.Filters.SavedReportList valid} filter list
			 *
			 * @param requestorUserInfo {@link com.intellica.client.common.UserInfo UserInfo} for authorization.
			 * Pass {@link com.intellica.client.common.UserInfo#getEmptyInstance() getEmptyInstance()} in case of report server runs in Security-Off mode.
			 *
			 * @return vector of {@link com.intellica.client.reportutils.SavedReport SavedReport} objects.
			 *
			 * @throws LayoutHandlerException
			 * */
			vecSavedReportList=lm.getSavedReportList(filter, requestorUserInfo);
		}
		catch(LayoutHandlerException lhe)
		{
			//If Category does not exist
			System.out.println ("Category: "+catId+" does not exist");	
		}
	
		// When vector of report list is not empty
		if(vecSavedReportList!=null)
		{
			//Iterating through the complete Vector list to get each Report's Details.
			for (int i = 0;i< vecSavedReportList.size(); i++)
			{
			
				SavedReport savedReport=(SavedReport) vecSavedReportList.get(i);
				System.out.println("Report Id for the saved report list-"+savedReport.getReportId());
				System.out.println("Report Name for the saved report list-"+savedReport.getRDFName());
				
			}//(end for loop)																					
	}//end if 
	}
	catch(InterfaceInitException iie) {
		iie.printStackTrace();
	}catch(IOException ioe){
		ioe.printStackTrace();			
	}
	
}
}
