//This Java API is used to get the complete list of all the Standard Reports from the Intellicus Repository.
//This would require User to provide User Info to authorize for Report layout operations.

//User would require to use following Intellicus jar files for using Intellicus APIs:
//1) intellica.jar
//2) log4ij.jar
//3) xercesImpl.jar
//4) xmlParserAPIs.jar
//Place above jar files in the classpath of your application.
//These jar files are located at  :  <Install_Path>\Intellicus\APIs

/***
* DISCLAIMER OF WARRANTY
* This source code is provided "as is" and without warranties as to performance or merchantability. 
* This source code is provided without any express or implied warranties whatsoever
*
**/

//Import Section
//Use intellica jar to import these classes 
import com.intellica.client.init.ReportClient; // Has Init Method
import com.intellica.client.common.Filter;
import com.intellica.client.common.InteraConstants;
import com.intellica.client.common.UserInfo; // Object used to pass in run report
import com.intellica.client.exception.InterfaceInitException;//Thrown as and when there is any error
															//in initializing the report Engine interface (REInterface). 
import com.intellica.client.exception.LayoutHandlerException;
import com.intellica.client.layout.LayoutManager;// for report layout management related operations			
import com.intellica.client.reportutils.Report;//Class contains the details of the irl file. 
import com.impetus.intera.layout.InteraReportLayout;
import com.impetus.intera.layout.LayoutProviderException;

import java.io.ByteArrayInputStream;//A ByteArrayInputStream contains an internal buffer that
import java.util.*;
import java.io.FileInputStream;
import java.io.BufferedInputStream;
import java.io.InputStream;

//This class is used to get the complete list of all the Standard Reports with its corresponding SQLs from the Report Server.
//The user would require to provide its identity i.e UserInfo. The required steps are :  
//1) Create a userinfo Object of current logged in User.
//2) Get all Standard reports from the report server.
//3) Get the properties of Standard Reports.
public class GetStandardReportList
{
	public static void main(String args[])
	{
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
			InputStream is= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																														//with the absolute path of ReportClient.properties.
			ReportClient.init(is);
			
			// Prepare a requestor user info bean object.
		    // This user should be present in Intellicus application.
			// when server running in security enabled mode
			//Syntax : public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
          //@param userId   - : Id of the User Logged-In.
          //@param password - : Password of the User Logged-In.
          //@param orgId    - : Organization Id from which User Logged-In.
			String	userId	=	"Admin";
			String password = "Admin";
			String organization = "Intellica";
			UserInfo userInfo =	new UserInfo(userId,password,organization);
			
			//To set the key,value pair for a particular filter field 
			Filter filter = new Filter();
			//Setting Filter to get only Standard/Studio reports
			filter.setFilterField(InteraConstants.SysParams.DSGN_MODE, "STUDIO");
			//Setting Filter to get Reports of particular Category
			filter.setFilterField(InteraConstants.UPXFilters.CATEGORY_ID, "Test");

			//com.intellica.client.layout.LayoutManager class is responsible for managing 
			//all report layout operations. The methods of this class are stateless and 
			//takes all required information such as requestor User Info etc. in each call.
			LayoutManager lm= new LayoutManager();
			
			//Vector that will be used to store the complete list of Reports in Repository.
			Vector vecReportList= new Vector();
		    
			try{
				//This method returns a vector of all report names from the report server 
				//The list will be restricted to accessible reports by this user
				//Syntax : public java.util.Vector getReportList(UserInfo userInfo)
				//@param userInfo - UserInfo for authorization. 
				vecReportList=lm.getReportList(filter,userInfo);
			
			}catch(LayoutHandlerException lhe)
			{
				lhe.printStackTrace();
			}
	         //If the Vector contains any element i.e. not equals to null
			if(vecReportList!=null)
			{ 				
				for (int j = 0;j< vecReportList.size(); j++)
				{
					//Type-casting into report Type
					Report report = (Report)vecReportList.get(j);
					System.out.println("Report Name = "+report.getMenuName());
					//Getting the Design Mode of each Report
					System.out.println("DesignMode = "+report.getDesignMode());
					//Getting the Category Name of the Report
					System.out.println("Category Name = "+report.getCategoryMenuName());
					//Getting the Deployment Type of each Report
					System.out.println("Deployment Type = "+report.getDeploymentType());					
					//Getting the Report Format of each Report
					System.out.println("Report Format = "+report.getReportFormat());					
					System.out.println();
				}//end for
			}//end if
		
		}
		catch(InterfaceInitException iie)
		{
		System.out.println ("Could not connect to report server::"+iie.getErrorMessage());
		//	iie.printStackTrace();
		}
		catch(Exception e)
		{
			e.printStackTrace();
		}
	}
}		
