//This Java API is used to move an existing report to another Destination Category.
//This would require user to provide requestorUserInfo to authorize for performing Reports related activities.
//User need to provide the ReportID that is to be moved and the Destination Category ID where it is to be moved.

//User would require to use following Intellicus jar files for using Intellicus APIs:
//1) intellica.jar
//2) log4ij.jar
//3) xercesImpl.jar
//4) xmlParserAPIs.jar
//Place above jar files in the classpath of your application.
//These jar files are located at  :  <Install_Path>\Intellicus\APIs

import com.intellica.client.common.UserInfo; //For getting user information
import com.intellica.client.exception.InterfaceInitException;//Thrown as and when there is any error
                                                             //in initializing the report Engine interface (REInterface). 
import com.intellica.client.exception.LayoutHandlerException;
import com.intellica.client.init.ReportClient;// Has Init Method
import com.intellica.client.layout.LayoutManager;// for report layout management related operations			
import com.intellica.client.reportutils.Report;//Class contains the details of the irl file. 


import java.io.FileInputStream;
import java.io.BufferedInputStream;
import java.io.InputStream;
/***
 * DISCLAIMER OF WARRANTY
 * This source code is provided "as is" and without warranties as to performance or merchantability. 
 * 
 * This source code is provided without any express or implied warranties whatsoever
 *
**/

/**
 * 
 * This class is used to move a report to the Category with given Category ID. 
 */
public class MoveReport {
	public static void main(String arg[])
	{
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
			InputStream is= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																														//with the absolute path of ReportClient.properties.
			ReportClient.init(is);
			
			// Prepare a requestor user info bean object.
			// This user should be present in Intellicus application.
			// Syntax : public requestorUserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating requestorUserInfo instance 
            // @param userId   - : Id of the User Logged-In.
            // @param password - : Password of the User Logged-In.
            // @param orgId    - : Organization Id from which User Logged-In.
			String	userId	=	"Admin";
			String password = "Admin";
			String organization = "Intellica";
			UserInfo requestorUserInfo	=	new UserInfo(userId,password,organization);
			
					
			// Create a Layout Manager class object 
			// for report layout management related operations			
			LayoutManager lm= new LayoutManager();
			
			// Report class contains the details of the irl file. 
			// This is the default constructor to create report object.
			Report report=new Report();
			
           //ReportID of the Report that is to be moved to new Category						
			String reportID="61A7DD7C-7372-FD11-E3BE-75F48124C041";
			
			
			// If want to get name of the Report with given Report ID, use method getReportDetails() to get its details.
			report=lm.getReportDetails(reportID,requestorUserInfo);	//To get the Report details of given Report 
			
			// Get the Report name and Set that name in the Report Object for the moved Report
			report.setMenuName(report.getReportName()); //Assigning same Report Name to  the moved Report
			
			//CategoryID of the Destination Category where the report needs to be moved	
			String destCategoryID="DemoCategory";

			
			//Method to copy the report to anther Category
			//param 1 : sourceReportId - source report id,mandatory argument for moving the report.
			//param 2 : destinationCategoryId - destination category id,where new report has to be moved.if this is null then report objects's category id will be taken as destination category.
			//param 3 : report - instance of Report class for move.
			//param 4 : requestorrequestorUserInfo - requestorUserInfo object for authorization. 
			lm.moveReport(reportID, destCategoryID, report,requestorUserInfo);
		}
		catch(InterfaceInitException iie)
		{
		System.out.println ("Could not connect to report server::"+iie.getErrorMessage());
		//	iie.printStackTrace();
		}
		catch(LayoutHandlerException lhe)
		{
			System.out.println("Unable to get the report details or unable to move the report");
		}
		catch(Exception e)
		{
			e.printStackTrace();
		}
	}	

}
