
//This Java API is used to publish an existing report with given Report ID from the Intellicus Repository and 
//This would require user to provide UserInfo to authorize for Reports Operations.

//User would require to use following Intellicus jar files for using Intellicus APIs:
//1) intellica.jar
//2) log4ij.jar
//3) xercesImpl.jar
//4) xmlParserAPIs.jar
//Place above jar files in the classpath of your application.
//These jar files are located at  :  <Install_Path>\Intellicus\APIs

/***
 * DISCLAIMER OF WARRANTY
 * This source code is provided "as is" and without warranties as to performance or merchantability. 
 * 
 * This source code is provided without any express or implied warranties whatsoever
 *
**/

 
import java.io.BufferedInputStream;
import java.io.FileInputStream;
import java.io.InputStream;

import com.intellica.client.report.ReportExecutor; // Has run report method
import com.intellica.client.report.ReportInfo;
import com.intellica.client.report.SaveReportInfo;
import com.intellica.client.init.ReportClient; // Has Init Method
import com.intellica.client.common.Enums;
import com.intellica.client.common.UserInfo; // Object used to pass in run report
import com.intellica.client.common.InteraConstants;
import com.intellica.client.utils.HashContainer; // Object used to pass parameters collection
import com.intellica.client.exception.ClientException ; // Exception class
import com.intellica.client.exception.InterfaceInitException;//Thrown as and when there is any error
															//in initializing the report Engine interface (REInterface). 


//This class is used to publish a report.
//Required steps are :
//1) Create a userinfo Object of current logged in User.
//2) Set Report Id which is to be published. 
//3) Set system parameters needed to publish the report.
//4) Set user parameters if required for that report  
//5) Send publish request to the server.

public class PublishReport
{
        
    public static void main(String args[])
    {
    	try{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
			InputStream is= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																														//with the absolute path of ReportClient.properties.
			ReportClient.init(is);
					
			// Prepare a requestor user info bean object.
			// This user should be present in Intellicus application.
			//Syntax : public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
            //@param userId   - : Id of the User Logged-In.
            //@param password - : Password of the User Logged-In.
            //@param orgId    - : Organization Id from which User Logged-In.
			String adminUserId = "Admin";
			String adminPassword = "Admin";
			String adminOrganization = "Intellica";
			UserInfo requestorUserInfo	=	new UserInfo(adminUserId,adminPassword,adminOrganization);

			
         	//fill up the system parameter values
         	//Report ID which is required to run
         	String reportId	= "Customer Order"; //4B0B9D74-0A7D-8B3A-A7B0-F6177295BF6E

         	if (args.length > 0) 
			{
				//get the ReportId from command-line
				reportId = args[0];
			}

			//Instantiate a collection object for setting system parameters
         	HashContainer hcSysParams = new HashContainer();

   
         	// This will set Id of the report.
	        hcSysParams.put("REPORT_ID","638CB7A6-F504-0ECD-008F-10B25253DCA8"); // In database mode only reportId needed.don't prefix category id
			// This will set the output format for the report.report format can be PDF/XLS/HTML
			hcSysParams.put("REPORT_FORMAT",InteraConstants.ReportFormats.PDF); 
			
							  	
		    //Instantiate a collection object for setting user/business parameters
		    HashContainer hcUserParams =new HashContainer();
	       
/*		    // fill up the user params if report contains any parameter
		    hcUserParams.put("Country","Australia"); // Parameter Name as created in the report layout(IRL)	       
		    hcUserParams.put("Role_ID","3818");
*/		
 		    //Instantiate Report Executor, Not Report Runner :-(
		    ReportExecutor report = new ReportExecutor();
		 
  		
		    ReportInfo repInfo = new ReportInfo(requestorUserInfo, hcSysParams, hcUserParams);
  		   
		    SaveReportInfo saveReportInfo = new SaveReportInfo(reportId);
		    
		    saveReportInfo.setProperty(Enums.Batch.SysParamNames.SAVEFILENAME, "abcdefg");
		    saveReportInfo.setProperty(Enums.Batch.SysParamNames.SAVEEXPIRYDATE, "");
		    repInfo.setSaveReportInfo(saveReportInfo);
		    
		    //Publishes a report by taking the values of system defined parameters and report 
			//parameters in HashContainer and publishes the Report.
			//This method generates the complete report, and then returns the control to 
			//the calling code. In this case, the calling code must catch the exceptions 
			//right at the calling place. 
		    report.saveReport(repInfo);
			
    	}
		catch(InterfaceInitException iie)
		{
		System.out.println ("Could not connect to report server::"+iie.getErrorMessage());
		//	iie.printStackTrace();
		}
		catch(ClientException ce)
		{
    		System.out.println("Error Message:"+ce.getExtMessage());
    	}    	   	
    	catch(Exception e)
		{
    		e.printStackTrace();
    	}
			
	 }
}


