//This Java API is used to run a report with given existing Report ID from the Intellicus Repository and 
//save it in the desired format.
//This would require user to provide UserInfo to authorize for Run Reports layout rights.

//User would require to use following Intellicus jar files for using Intellicus APIs:
//1) intellica.jar
//2) log4ij.jar
//3) xercesImpl.jar
//4) xmlParserAPIs.jar
//Place above jar files in the classpath of your application.
//These jar files are located at  :  <Install_Path>\Intellicus\APIs

/***
 * DISCLAIMER OF WARRANTY
 * This source code is provided "as is" and without warranties as to performance or merchantability. 
 * 
 * This source code is provided without any express or implied warranties whatsoever
 *
**/

 
import com.intellica.client.report.ReportExecutor; // Has run report method
import com.intellica.client.init.ReportClient; // Has Init Method
import com.intellica.client.common.UserInfo; // Object used to pass in run report
import com.intellica.client.common.InteraConstants;
import com.intellica.client.utils.HashContainer; // Object used to pass parameters collection
import com.intellica.client.exception.ClientException ; // Exception class
import com.intellica.client.exception.InterfaceInitException;//Thrown as and when there is any error
															//in initializing the report Engine interface (REInterface). 
import java.io.ByteArrayOutputStream; // For collecting report output in file format
import java.io.FileNotFoundException;
import java.io.FileOutputStream;  // for writing file to disk
import java.io.IOException;

import java.io.FileInputStream;
import java.io.BufferedInputStream;
import java.io.InputStream;


//This class is used to run a report and save it in the desired format.
//Required steps are :
//1) Create a userinfo Object of current logged in User.
//2) Set Report Id for running report. 
//3) Set system parameters needed to run the report.
//4) Set user parameters if required for running report  
//5) Send run request to server and save the report output on the disk in the desired output format.

public class RunReport
{
        
    public static void main(String args[])
    {
		// Static Init call. it will read the properties for report server related attributes 
		// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
		//in the INTERA_HOME property of the ReportClient.properties file.

    	try{	
    	  	InputStream is= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																														//with the absolute path of ReportClient.properties.
			ReportClient.init(is);
		
			
			// Prepare a requestor user info bean object.
			// This user should be present in Intellicus application.
			//Syntax : public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
            //@param userId   - : Id of the User Logged-In.
            //@param password - : Password of the User Logged-In.
            //@param orgId    - : Organization Id from which User Logged-In.
			String adminUserId = "Admin";
			String adminPassword = "Admin";
			String adminOrganization = "Intellica";
			UserInfo requestorUserInfo	=	new UserInfo(adminUserId,adminPassword,adminOrganization);
			
			//Instantiate a collection object for setting system parameters
         	HashContainer hcSysParams = new HashContainer();
	         
         	//fill up the system parameter values
         	//Report ID which is required to run
         	String reportId	= "Customer Report";
	        
	        // This will set Id of the report.
	        hcSysParams.put("REPORT_ID",reportId); // In database mode only reportId needed.don't prefix category id
			// This will set the output format for the report.report format can be PDF/XLS/HTML
			hcSysParams.put("REPORT_FORMAT",InteraConstants.ReportFormats.PDF); 
			
							  	
		    //Instantiate a collection object for setting user/business parameters
		    HashContainer hcUserParams =new HashContainer();
	       
		    // fill up the user params if report contains any parameter
		    hcUserParams.put("Country","Australia"); // Parameter Name as created in the report layout(IRL)	       
		    hcUserParams.put("Role_ID","3818");
		
 		    //Instantiate Report Executor, Not Report Runner :-(
		    ReportExecutor report = new ReportExecutor();
		 
  		
  		    // RUN !! This is the method call for SYNCHRONOUS execution.
  		    // After the call, you should have your output file in reportdata
	 	
	 	    // Instantiate stream object
            ByteArrayOutputStream reportData = new ByteArrayOutputStream();
	 	
			 //Executes a report by taking the values of system defined parameters and report 
			 //parameters in parameters as HashContainer and gives the generated report data
			 //in the passed outputStream.
			 //This method generates the complete report, and then returns the control to 
			 //the calling code. In this case, the calling code must catch the exceptions 
			 //right at the calling place. The calling code can use the output stream after 
			 //the method call. 
			 report.runReport(requestorUserInfo,hcSysParams,hcUserParams,null,reportData,true);
			
			String savedFile = "C:\\SampleReport.pdf";
			//save the byte array to local file. 
			 FileOutputStream   fos = new FileOutputStream(savedFile); // give .pdf for PDF, .xls for XLS 
			 reportData.writeTo(fos);
    	}
		catch(InterfaceInitException iie)
		{
		System.out.println ("Could not connect to report server::"+iie.getErrorMessage());
		//	iie.printStackTrace();
		}
		catch(ClientException ce)
		{
    		System.out.println("Error Message:"+ce.getExtMessage());
    	}
    	catch(FileNotFoundException fnfe)
		{
    		System.out.println("Error Message:"+fnfe.getMessage());
    	}
    	catch(IOException ioe)
		{
    		System.out.println("Error Message:"+ioe.getMessage());
    	}
    	catch(Exception e)
		{
    		e.printStackTrace();
    	}
			
	 }
}


