/* This sample code is to add a new Query Object in the Intellicus repository.
 * User would require to use following Intellicus jar files for using Intellicus APIs:
 * 1) intellica.jar
 * 2) log4ij.jar
 * 3) xercesImpl.jar
 * 4) xmlParserAPIs.jar
 * Place above jar files in the classpath of your application.
 * These jar files are located at  :  <Install_Path>\Intellicus\APIs
 */

/***
 * DISCLAIMER OF WARRANTY
 * This source code is provided "as is" and without warranties as to performance or merchantability. 
 * 
 * This source code is provided without any express or implied warranties whatsoever
 *
**/



import com.intellica.client.common.UserInfo; // user info bean 
import com.impetus.intera.reportobjects.ReportObjectException;
import com.impetus.intera.reportobjects.ReportObjectManager;//This class is used for Report Object related operations.
import com.impetus.intera.reportobjects.ReportObject;//This class is super class of all the report objects 
import com.impetus.intera.reportobjects.QueryObject;// This class contains all the details about the query object.
import com.impetus.intera.reportobjects.QueryObjectColumn;//The class contain all the information relate COLUMN Tag of Query Object
import com.intellica.client.exception.BaseException;// This class is the base class of all the application generated exceptions engine may throw.
import com.intellica.client.exception.InterfaceInitException;//Thrown as and when there is any error
                                                              //in initializing the report Engine interface (REInterface). 
import com.impetus.intera.layout.sqleditor.SQLEditor;//This class contains properties and parsing logic for the SQLEDITOR of the report. 
import com.intellica.client.common.Enums;// Has Enums for the constants used
import java.util.ArrayList;
import java.io.FileInputStream;
import java.io.BufferedInputStream;
import java.io.InputStream;

public class AddQOToCategory
{
	public static void main(String args[]){ 
		try{
			
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
			InputStream is= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																														//with the absolute path of ReportClient.properties.
			
			com.intellica.client.init.ReportClient.init(is);
			
		     // Prepare a requestor user info bean object.
			// This user should be present in Intellicus application.
			//Syntax : public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
            //@param userId   - : Id of the User Logged-In.
            //@param password - : Password of the User Logged-In.
            //@param orgId    - : Organization Id from which User Logged-In.
			String	userId	=	"Admin";
			String password = "Admin";
			String organization = "Intellica";
			UserInfo requestorUserInfo	=	new UserInfo(userId,password,organization);
			
			
			//This class contains method to get/replace/add/delete a Query object(QO)
			ReportObjectManager reportObjectManager = new ReportObjectManager();
			
			//To create the Object of Report Object class.
			//public static ReportObject createReportObject(java.lang.String roType)
			QueryObject qoObj=(QueryObject)ReportObject.createReportObject(Enums.IRO.TYPE.QUERY);
			
		    //This will be used as Name of the Query Object. 	
	    	String qoName = "testQO";
	    	//To set the name of the Query Object.	
	    	 qoObj.setName(qoName);
		    //To set the ID for Query Object manually
		    qoObj.setId("testQO");
		    //Set Category ID in order to create query object in a specific categroy.
		    qoObj.setCategoryId("F6D1290E-B070-0509-42C7-B7FD3556910C");
		    
		    //To set caching true or false for the Query Object
		    qoObj.setCached(true);
		    //To set the description for the Query Object
		    qoObj.setDescription("This Query gives information related to the Countries.");
		    //To set the Connection type for the Query Object.It may be Default Or Named. 
		    qoObj.setConnectionType("Default");
		    //If Connection Type is Named then To set the Connection name for the Querry Object.
		    qoObj.setConnectionName("ReportDB");
			//Whether to set the Group caption or not
		    qoObj.setGroupCaption(true);
		    //To set the source for the Query Object
		    qoObj.setSource("SQL");
		    //Whether to set the filter mandatory for any field or not
		    qoObj.setIsFilterMandatory(false);
		    
		    //Sql Query that is to be set
		    String sqlQuery = "select COUNTRY.* from COUNTRY";
		    //Create the SQLEditor Object.
		    SQLEditor sqlEditor = qoObj.getSqlEditor();
		    //To set the SQL for fields in Query Object.
		    //public void setSQL(java.lang.String newQueryObjectSQL,boolean isEditDirty)
		    sqlEditor.setSQL(sqlQuery,true);	
		    
		    //Adding a new Column in the Query Object
		    //To add the columns in Query Object.
		    // QueryObjectColumn(java.lang.String columnName,
		    //                   java.lang.String caption,
		    //                   java.lang.String width,
		    //                   java.lang.String dataType)
			QueryObjectColumn qoc1 = new QueryObjectColumn("COUNTRY_CD","COUNTRY_CD","","");
			QueryObjectColumn qoc2 = new QueryObjectColumn("COUNTRY","COUNTRY","","");
			QueryObjectColumn qoc3 = new QueryObjectColumn("FLAG","FLAG","","");
			
			//Setting other Attributes for the above Column name "JOB"
			//To Set the Alignment for the Column
			qoc1.setAlignment(1);  // Left Alignment: 0 , Right Alignment: 1
			//To set the Data Type 
			qoc1.setDataType("Number");
			//Whether to hide this column or not, True : For hidding the Column
			qoc1.setHidden(false);
			//To set the width
			qoc1.setWidth("20");
			//To set this column in a group
			qoc1.setGroupLabelCaption("Job");
			//To set the Output Format
			qoc1.setFormat("Number");
			//To set hyperlink for this column 
			String hyperLink = "DRILLDOWN:REPORT_ID=E85A9025-6AB9-4EDB-0DE3-E0533FAFAB04:ACTION_CODE=002:MENU_NAME=All Country  Sales:CATEGORY_ID=4F9245A7-D639-4F99-604D-F32641B77725:DSGN_MODE=ADHOC:~TARGET=0";
			//qoc1.setHyperlink(hyperLink);
									
			//Creting ArrayList that contains object of QueryObjectColumn as its elements 
			ArrayList ArrColumn=new ArrayList();
			//Adding the objects of QueryObjectColumn to the ArrayList
			ArrColumn.add(qoc1);
			ArrColumn.add(qoc2);	
			ArrColumn.add(qoc3);
						
			//To set the columns in the Query Object by passing the ArrayList as arguement.
     		//public void setColumnDetails(java.util.ArrayList columnDetails)
			qoObj.setColumnDetails(ArrColumn);
		    //To Add and Save the Query Object, use addReportObject() method of ReportObjectManager
     		//addReportObject(com.impetus.intera.reportobjects.ReportObject reportObject,
            //                com.intellica.client.common.UserInfo userInfo)
    		reportObjectManager.addReportObject(qoObj,requestorUserInfo);
     					
		}
		catch(InterfaceInitException iie)
		{
		System.out.println ("Could not connect to report server::"+iie.getErrorMessage());
		//	iie.printStackTrace();
		}
		catch(ReportObjectException roe){
			System.out.println("Error Message:"+roe.getErrorMessage());
		}
		catch(Exception e)
		{
			e.printStackTrace();
		}
	}//End of the main.	
}