/* This program adds column to the Intellicus Repository or removes a column from the Intellicus Repository.
 * User would require to use following Intellicus jar files for using Intellicus APIs:
 * 1) intellica.jar
 * 2) log4ij.jar
 * 3) xercesImpl.jar
 * 4) xmlParserAPIs.jar
 * Place above jar files in the classpath of your application.
 * These jar files are located at  :  <Install_Path>\Intellicus\APIs
 */


/***
 * DISCLAIMER OF WARRANTY
 * This source code is provided "as is" and without warranties as to performance or merchantability. 
 * 
 * This source code is provided without any express or implied warranties whatsoever
 *
**/

import com.intellica.client.common.UserInfo; // user info bean 
import com.impetus.intera.reportobjects.ReportObjectManager;//This class is used for Report Object related operations.
import com.impetus.intera.reportobjects.ReportObject;//This class is super class of all the report objects 
import com.impetus.intera.reportobjects.QueryObject;// This class contains all the details about the query object.
import com.impetus.intera.reportobjects.QueryObjectColumn;//The class contain all the information relate COLUMN Tag of Query Object
import com.intellica.client.exception.BaseException;// This class is the base class of all the application generated exceptions engine may throw.
import com.intellica.client.exception.InterfaceInitException;//Thrown as and when there is any error
                                                              //in initializing the report Engine interface (REInterface). 
import com.impetus.intera.layout.sqleditor.SQLEditor;//This class contains properties and parsing logic for the SQLEDITOR of the report. 
import com.intellica.client.common.Enums;// Has Enums for the constants used

import java.io.FileInputStream;
import java.io.BufferedInputStream;
import java.io.InputStream;

/*
 * This class is used to add a column to the Intellicus repository or removes a column 
 *from the Intellicus Repository. 
 */
public class AddRemoveColumn{
	public static void main(String args[])
		{
		    // Prepare a requestor user info bean object.
			// This user must have Admin rights to perform user management actions
			// such as create user
			// This user should be present in Intellicus application.
			//Syntax public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
            //@param userId   - : Id of the User Logged-In.
            //@param password - : Password of the User Logged-In.
            //@param orgId    - : Organization Id from which User Logged-In.
			String userId = "Admin";
			String password = "Admin";
			String organization = "Intellica";
		    UserInfo requestorUserInfo	=	new UserInfo(userId,password,organization);
			
			try
			{
				// Static Init call. it will read the properties for report server related attributes 
				// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
				//in the INTERA_HOME property of the ReportClient.properties file.
				InputStream is= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																															//with the absolute path of ReportClient.properties.
				
				com.intellica.client.init.ReportClient.init(is);

				//This class contains method to get/replace/add/delete a Query object(QO)
				ReportObjectManager reportObjectManager = new ReportObjectManager();
			
				String qoName = "QO";			
			
				QueryObject qoObj = (QueryObject)reportObjectManager.getReportObjectByName(Enums.IRO.TYPE.QUERY,qoName,requestorUserInfo);
			
			
				//The class contain all the information relate COLUMN Tag of Query Object 
				//create the coloumn to add			
				QueryObjectColumn qoc = new QueryObjectColumn("BANKS.BANKID","BankID","3","NUMBER");
				//add the column to query object
				qoObj.addColumn(qoc);			
					
				//remove the column	
				//removeStatus is true if delete succeeds else false		
				boolean removeStatus = qoObj.removeColumn("ID");
			
				//modify the sql to add and remove the columns in it
				SQLEditor sqlEditor = qoObj.getSqlEditor();
				//if the complete sql differs from the sql in designed sql
				if(sqlEditor.isEditDirty())
				{
					sqlEditor.setSQL("select BANKS.BANKID from BANKS",true);
				}
				else
				{
					//String previousSelectClause = sqlEditor.getClause().getSelect();
					sqlEditor.getClause().setSelect("BANKS.BANKID");
					String completeSql = sqlEditor.createSQL();
					sqlEditor.setSQL(completeSql,false);
				}
			
				//save the query object in intellicus 
				String status = reportObjectManager.replaceReportObject(qoObj.toString(),requestorUserInfo);
			
				//if the status string contains error 
				if(status.toLowerCase().indexOf("error")!=-1)
				{
					System.out.println ("operation status "+status);
					//throw an excpetion if required
			}
			
			
			}
			catch(InterfaceInitException iie)
			{
			System.out.println ("Could not connect to report server::"+iie.getErrorMessage());
			//	iie.printStackTrace();
			}
			catch(BaseException roe)
			{
			//roe.printStackTrace();
				System.out.println ("code:"+roe.getErrCode());
				System.out.println ("code:"+roe.getErrorMessage());
			}
			catch(Exception e){
				
				System.out.println ("code:"+e.getMessage());
			}
	}	
}