/* This program is used to get a report object by name from the Repository.It also retrieves the attributes of the query object.
 * User would require to use following Intellicus jar files for using Intellicus APIs:
 * 1) intellica.jar
 * 2) log4ij.jar
 * 3) xercesImpl.jar
 * 4) xmlParserAPIs.jar
 * Place above jar files in the classpath of your application.
 * These jar files are located at  :  <Install_Path>\Intellicus\APIs
 */


/***
 * DISCLAIMER OF WARRANTY
 * This source code is provided "as is" and without warranties as to performance or merchantability. 
 * 
 * This source code is provided without any express or implied warranties whatsoever
 *
**/
// Import Section
// Use intellica jar to import these classes
import com.intellica.client.common.UserInfo; // user info bean 
import com.impetus.intera.reportobjects.ReportObjectManager;//This class is used for Report Object related operations.
import com.impetus.intera.reportobjects.QueryObject;// This class contains all the details about the query object.
import com.impetus.intera.reportobjects.QueryObjectColumn;//The class contain all the information relate COLUMN Tag of Query Object
import com.intellica.client.exception.BaseException;// This class is the base class of all the application generated exceptions engine may throw.
import com.intellica.client.exception.InterfaceInitException;//Thrown as and when there is any error
                                                             //in initializing the report Engine interface (REInterface). 
import com.intellica.client.common.Enums;// Has Enums for the constants used
import java.util.ArrayList;
import java.io.FileInputStream;
import java.io.BufferedInputStream;
import java.io.InputStream;

public class GetReportObjectByName
{
	

	public static void main(String args[])
	{ 
		try
			{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
			InputStream is= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																														//with the absolute path of ReportClient.properties.
			
			com.intellica.client.init.ReportClient.init(is);
						
		    // Prepare a requestor user info bean object.
			// This user must have Admin rights to perform user management actions
			// such as create user
			// This user should be present in Intellicus application.
			//Syntax public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
            //@param userId   - : Id of the User Logged-In.
            //@param password - : Password of the User Logged-In.
            //@param orgId    - : Organization Id from which User Logged-In.
			String userId = "Admin";
			String password = "Admin";
			String organization = "Intellica";
		    UserInfo requestorUserInfo	=	new UserInfo(userId,password,organization);
			
			
			//This class contains method to get/replace/add/delete a Query object(QO)
			ReportObjectManager reportObjectManager = new ReportObjectManager();
			
			String qoName = "All Country Sales";
	    	
			//To create the Object of Query Object class.
			QueryObject qoObj=(QueryObject)reportObjectManager.getReportObjectByName(Enums.IRO.TYPE.QUERY,qoName,requestorUserInfo);
			
			//To get the number of columns present in the Query Object
		    int columnCount=qoObj.getColumnCount();
			//This will display the columns present.
		    ArrayList arrColumn=qoObj.getColumnDetails();
			//This will give the connection name.If the connection is set as default connection then no name is displayed
	        String connectionName=qoObj.getConnectionName();
			//This will give the type of connection
	        String connectionType=qoObj.getConnectionType();
			//This will give the name of the query object
	        String qOName=qoObj.getName();	 
			//This will give the id of the query object
	        String qOId=qoObj.getId();
			//This will give the type of query object
	        String qOType=qoObj.getType();
            //This will give the source of query object like SQL or XML.
	        String qOSrc=qoObj.getSource();
			//This will give the class of the query object.The method returns runtime class of the object 
	        Class<? extends QueryObject> qOClass=qoObj.getClass();
			//This will give the description of the query object if given.Otherwise nothing is displayed.
	        String desc=qoObj.getDescription();
			//This will give the fetch data in SQL
	        String fetchDataSQL=qoObj.getFetchDataSQL();
			//This will give the fetch data XML
	        String fetchDataXML=qoObj.getFetchDataXML();
            //This will give the number of filters being applied .
	        int filterCount=qoObj.getFilterCount();
            //This will return the index of the formula field.Required to specify the the field.
	        int formulaFieldIndex=qoObj.getFormulaFieldIndex("SalesAmount");
	                
	        System.out.print("\n");
	        System.out.print("Query Object Id              "+qOId);
	        System.out.print("\n");
	        System.out.print("Query Object Name            "+qOName);
	        System.out.print("\n");
	        System.out.print("Query Object Type            "+qOType);
	        System.out.print("\n");
	        System.out.print("Source                       "+qOSrc);
	        System.out.print("\n");
	        System.out.print("Total Number of Column       "+columnCount);
	        System.out.print("\n");
	        System.out.print("Connection Type              "+connectionType);
	        System.out.print("\n");
	        System.out.print("Connection Name              "+connectionName);
	        System.out.print("\n");
	        System.out.print("Class                        "+qOClass);
	        System.out.print("\n");
	        System.out.print("Description                  "+desc);
	        System.out.print("\n");
	        System.out.print("FetchDataSQL                 "+fetchDataSQL);
	        System.out.print("\n");
	        System.out.print("FetchDataXML                 "+fetchDataXML);
	        System.out.print("\n");
	        System.out.print("FilterCount                  "+filterCount);
	        System.out.print("\n");
	        System.out.print("Formula Field                "+formulaFieldIndex);
	            
	       
	        System.out.print("\n");
	        System.out.print("The columns present in this query object are: "); 
	        System.out.print("\n");
	        System.out.print("----------------------------------------------");
	        System.out.print("\n");

	        for ( int i =0;i<arrColumn.size();i++)
	        {
	        	QueryObjectColumn Column=(QueryObjectColumn)arrColumn.get(i);
	        	System.out.println(Column.getColumnName());
	        	System.out.print("\n");
	        }	
			}
		catch(InterfaceInitException iie)
		{
		System.out.println ("Could not connect to report server::"+iie.getErrorMessage());
		//	iie.printStackTrace();
		}
		catch(BaseException roe)
		{
			
			System.out.println ("code"+roe.getErrCode());
			System.out.println ("code"+roe.getErrorMessage());
		}
		catch(Exception e){
			System.out.println ("code"+e.getMessage());
		}
					
		
	}//End of the main.	
}