/* This Java API is used to get the list of Report Objects i.e. Query Objects and Parameter Objects.
 * This would require user to provide UserInfo to authorize for Reports related Activites.
 * User would require to use following Intellicus jar files for using Intellicus APIs:
 * 1) intellica.jar
 * 2) log4ij.jar
 * 3) xercesImpl.jar
 * 4) xmlParserAPIs.jar
 * Place above jar files in the classpath of your application.
 * These jar files are located at  :  <Install_Path>\Intellicus\APIs
 */

//User would require to use following Intellicus jar files for using Intellicus APIs:
//1) intellica.jar
//2) log4ij.jar
//3) xercesImpl.jar
//4) xmlParserAPIs.jar
//Place above jar files in the classpath of your application.
//These jar files are located at  :  <Install_Path>\Intellicus\APIs

 //This class returns list of report objects
 //The parameter objects and the query objects are displayed as the user desires to view.
 // Import Section
 // Use intellica jar to import these classes

/***
 * DISCLAIMER OF WARRANTY
 * This source code is provided "as is" and without warranties as to performance or merchantability. 
 * 
 * This source code is provided without any express or implied warranties whatsoever
 *
 **/
 
import com.intellica.client.common.UserInfo; // user info bean 
import com.impetus.intera.reportobjects.ReportObjectException;//This exception is thrown when unable to handle report objects.
import com.impetus.intera.reportobjects.ReportObjectManager;//This class is used for Report Object related operations.
import com.impetus.intera.reportobjects.ReportObject;//This class is super class of all the report objects 
import com.intellica.client.common.Enums;// Has Enums for the constants used
import com.intellica.client.exception.InterfaceInitException;//Thrown as and when there is any error
                                                             //in initializing the report Engine interface (REInterface). 
import java.util.ArrayList;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.lang.String;
import java.io.FileInputStream;
import java.io.BufferedInputStream;
import java.io.InputStream;


/*
 * This class is used to get either the list of Query Object or Parameter Object.
 */
public class GetReportObjectList
{
	public static void main(String args[])
	{ 
		try
		{
			
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
			InputStream is= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																														//with the absolute path of ReportClient.properties.
			
			com.intellica.client.init.ReportClient.init(is);
		
			
			// Prepare a requestor user info bean object.
			// This user should be present in Intellicus application.
			//Syntax : public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
            //@param userId   - : Id of the User Logged-In.
            //@param password - : Password of the User Logged-In.
            //@param orgId    - : Organization Id from which User Logged-In.
			String	userId	=	"Admin";
			String password = "Admin";
			String organization = "Intellica";
			UserInfo requestorUserInfo	=	new UserInfo(userId,password,organization);
						
		   	//This class contains method to get/replace/add/delete a Query object(QO) or Parameter object(PO)
		   	ReportObjectManager reportObjectManager = new ReportObjectManager();
		
			// This array stores the list of Report Object		
		   	ArrayList reportObjList=new ArrayList();
         
		   	System.out.println("What report objects you want to have ?");
		   	System.out.println("Please Choose 1 for parameter objects :");
		   	System.out.println("Please Choose 2 for query objects :");
		   
		   	BufferedReader br=new BufferedReader (new InputStreamReader(System.in));//Reading the user choice
	       	int choice=Integer.parseInt(br.readLine());//the choice of the user
	            
	       	//If User want to get the List of Parameter Object
	       	if(choice==1)
	       	{	  
		        //This class contains all the details about the parameter object, that is, all the details of <PO> tag 
		        ReportObject repObjectPrm=ReportObject.createReportObject(Enums.IRO.TYPE.PARAMETER);
		   	    
		   	    //Method used to get the list of Report Object i.e. Parameter Object in this case 
		   	    reportObjList=reportObjectManager.getReportObjectList(repObjectPrm.getType(),requestorUserInfo);	
	          
	       	}
	       	
	       	//If User want to get the List of Query Object
	       	else if(choice==2)
	       	{
	        	 //This class contains all the details about the parameter object, that is, all the details of <PO> tag 
	        	 ReportObject repObjectQuery=ReportObject.createReportObject(Enums.IRO.TYPE.QUERY);
			   	 
			   	 //Method used to get the list of Report Object i.e. Query Object in this case 
			   	 reportObjList=reportObjectManager.getReportObjectList(repObjectQuery.getType(),requestorUserInfo);  
	       	}
	        
			
			// If Arraylist contains some elements
		   	if(reportObjList!=null && !reportObjList.isEmpty())
		   	{
				  //Iterate the Arraylist 
				  for(int i=0;i<reportObjList.size();i++)
				  {
					     ReportObject repObject=(ReportObject)reportObjList.get(i);
					     System.out.println ("");
					  
						 System.out.println ("report object name: "+repObject.getName());
						 System.out.println ("report object type: "+repObject.getType());
				   }	
		   	}
		   	
		   	//If Arraylist is empty
 		   	else
 		   	{
		    	System.out.println ("No report objects exits");	

 		    }
        }//end try
		catch(InterfaceInitException iie)
		{
		System.out.println ("Could not connect to report server::"+iie.getErrorMessage());
		//	iie.printStackTrace();
		}
		catch(ReportObjectException roe){
			System.out.println("Error Message:"+roe.getExtMessage());
		}
		catch(IOException ioe){
			System.out.println("Error Message:"+ioe.getMessage());
			
		}
		catch(Exception e)
		{
			e.printStackTrace();
			
		}
	}
}		
