/* This Sample code retrives the list of report objects for a specific report
 * There will be single DataSource/ReportObject/QueryObject for a specific report
 * User would require to use following Intellicus jar files for using Intellicus APIs:
 * 1) intellica.jar
 * 2) log4ij.jar
 * 3) xercesImpl.jar
 * 4) xmlParserAPIs.jar
 * Place above jar files in the classpath of your application.
 * These jar files are located at  :  <Install_Path>\Intellicus\APIs
 */

/***
 * DISCLAIMER OF WARRANTY
 * This source code is provided "as is" and without warranties as to performance or merchantability. 
 * 
 * This source code is provided without any express or implied warranties whatsoever
 *
 **/
// Import Section
import java.io.FileInputStream;
import java.io.BufferedInputStream;
import java.io.InputStream;

// Use intellica jar to import these classes


import com.impetus.intera.layout.adhoc.AdhocLayoutException;
import com.impetus.intera.layout.adhoc.AdhocReportLayout;//This class holds information about complete Adhoc Report Layout.
                                                         //It holds informatiom about DataSource,Template,Filters,Groups,
                                                         //Charts,Matrix,Sumarries,Sort-orders used for desiging this Adhoc Report.

import com.intellica.client.common.UserInfo;// Object used to pass in run report
import com.intellica.client.exception.InterfaceInitException;//Thrown as and when there is any error
                                                             //in initializing the report Engine interface (REInterface). 
import com.intellica.client.exception.LayoutHandlerException;
import com.intellica.client.init.ReportClient;// Has Init Method
import com.intellica.client.layout.LayoutManager;// for report layout management related operations
import com.intellica.client.reportutils.Report;//Class contains the details of the irl file. 
import java.io.ByteArrayInputStream;//A ByteArrayInputStream contains an internal buffer that
                                    //contains bytes that may be read from the stream.

//In this class ,the report id is required to be provided,corresponding to which the
//report objects retrieved from the Intellicus repository 
public class GetReportObjectforReport 
{
	public static void main(String args[])
	{
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
			InputStream is= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																														//with the absolute path of ReportClient.properties.
			
			com.intellica.client.init.ReportClient.init(is);
			
			//Prepare a requestor user info bean object.
			// This user must have Admin rights to perform user management actions
			// such as create user
			// This user should be present in Intellicus application.
			//Syntax public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
            //@param userId   - : Id of the User Logged-In.
            //@param password - : Password of the User Logged-In.
            //@param orgId    - : Organization Id from which User Logged-In.

			String userId = "Admin";
			String password = "Admin";
			String organization = "Intellica";
			UserInfo requestorUserInfo	=	new UserInfo(userId,password,organization);
			
			//Create a Layout Manager class object 
			// for report layout management related operations			
			LayoutManager lm= new LayoutManager();
			Report report=new Report();
			//Report id provided whose report objects is required to be retrieved 
		    String reportId="1969CB7E-F0EB-0625-8985-18201F703E6B";//System generated report id
			report.setReportId(reportId);
			
			//This method returns the menu Name
			//Syntax :public java.lang.String getMenuName() 
			System.out.println("report="+report.getMenuName());
			
			//This method Returns the byte array containing the report layout for the 
		    //given reportID from the report layout repository.
		    //public byte[] getIRLFile(java.lang.String reportId,UserInfo userInfo)
            //@param : reportId - The report id of the requested report layout.
            //@param : userInfo - UserInfo object use to validate the user against the application. 
		 	byte reportIRL[]=lm.getIRLFile(report.getReportId(),requestorUserInfo);
			
			//New object of AdhocReportLayout is created
			AdhocReportLayout adhocReportLayout=new AdhocReportLayout();
			
			//This method is used for parsing of Nodes.This method can be
		    //used to parse individual report object.
		   	adhocReportLayout.parseXml(new ByteArrayInputStream(reportIRL));
		    
		    //Data Source means Report Object used or Query Object used.
			System.out.println("REPORT: "+report.getMenuName()+", DATA SOURCE: "+adhocReportLayout.getDataSource().getName()+", TYPE: "+adhocReportLayout.getDataSource().getType());
				
					
	      
	   }
		catch(InterfaceInitException iie)
		{
		System.out.println ("Could not connect to report server::"+iie.getErrorMessage());
		//	iie.printStackTrace();
		}
		
		catch(LayoutHandlerException lhe){
		  System.out.println("Error Message:"+lhe.getErrorMessage()); 
	   }
	   catch(AdhocLayoutException ale){
		   System.out.println("Error Message:"+ale.getErrorMessage()); 
	   }
	   catch(Exception e)
	   {
			e.printStackTrace();
	   }
			
     }
 }

