/* This Sample code retrives the list of report objects for the reports of a specific category.
 * User would require to use following Intellicus jar files for using Intellicus APIs:
 * 1) intellica.jar
 * 2) log4ij.jar
 * 3) xercesImpl.jar
 * 4) xmlParserAPIs.jar
 * Place above jar files in the classpath of your application.
 * These jar files are located at  :  <Install_Path>\Intellicus\APIs
 */


/***
 * DISCLAIMER OF WARRANTY
 * This source code is provided "as is" and without warranties as to performance or merchantability. 
 * 
 * This source code is provided without any express or implied warranties whatsoever
 *
 **/
// Import Section
// Use intellica jar to import these classes

import com.impetus.intera.layout.adhoc.AdhocLayoutException;
import com.impetus.intera.layout.adhoc.AdhocReportLayout;//This class holds information about complete Adhoc Report Layout.
                                                         //It holds informatiom about DataSource,Template,Filters,Groups,
                                                         //Charts,Matrix,Sumarries,Sort-orders used for desiging this Adhoc Report.

import com.intellica.client.common.UserInfo;// Object used to pass in run report
import com.intellica.client.exception.LayoutHandlerException;
import com.intellica.client.init.ReportClient;// Has Init Method
import com.intellica.client.layout.LayoutManager;// for report layout management related operations
import com.intellica.client.reportutils.Report;//Class contains the details of the irl file. 
import java.io.ByteArrayInputStream;//A ByteArrayInputStream contains an internal buffer that
                                    //contains bytes that may be read from the stream.
import java.util.ArrayList;//Implements all optional list operations, and permits all elements, including null.
                           //In addition to implementing the List interface, this class provides methods to 
                           //manipulate the size of the array that is used internally to store the list.
import java.util.List;//For operation using list
import java.util.Vector;//The Vector class implements a growable array of objects. 
                        //Like an array, it contains components that can be accessed 
                        //using an integer index. However, the size of a Vector can grow 
                        //or shrink as needed to accommodate adding and removing items after 
                        //the Vector has been created.
import java.io.FileInputStream;
import java.io.BufferedInputStream;
import java.io.InputStream;

//In this class category Id is required to be provided ,corresponding to which the reports are retrieved 
// and corresponding to each report,list of report objects are retrieved.
import com.intellica.client.exception.InterfaceInitException;//Thrown as and when there is any error
// in initializing the report Engine interface (REInterface). 

public class GetReportObjectsForCategory 
{

	public static void main(String args[])
	{
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
			InputStream is= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																														//with the absolute path of ReportClient.properties.
			
			com.intellica.client.init.ReportClient.init(is);
			
			//Prepare a requestor user info bean object.
			// This user must have Admin rights to perform user management actions
			// such as create user
			// This user should be present in Intellicus application.
			//Syntax public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
            //@param userId   - : Id of the User Logged-In.
            //@param password - : Password of the User Logged-In.
            //@param orgId    - : Organization Id from which User Logged-In.

			String	userId	=	"Admin";
			String password = "Admin";
			String organization = "Intellica";
			UserInfo requestorUserInfo	=	new UserInfo(userId,password,organization);
			
			//Create a Layout Manager class object 
			// for report layout management related operations			
			LayoutManager lm= new LayoutManager();
			Vector vecReportList= new Vector();
	

			String catId="4F9245A7-D639-4F99-604D-F32641B77725";//System generated category id.
             
			 //The method requests report server and returns the reports present in the Category 
			 //repository under given report category, both public and private to requestor user. 
			//The public reports will be restricted to those reports that the requestorUserInfo has 
			//access to read. 
		    // This will return Vector of report objects for the catId.
			//Syntax : public java.util.Vector getReportListForCategory(java.lang.String categoryId,UserInfo requestorUserInfo)
            //@param : categoryId -The category Id of the category from which, the report layout list is requested. 
			//         Intellicus allows category ids upto 256 charecters long.
            //@param : requestorUserInfo - UserInfo for authorization. 
		    vecReportList=lm.getReportListForCategory(catId,requestorUserInfo);

		   // When vector of report list is not empty
		   if(vecReportList!=null)
		   {
			 List reportObjectList=new ArrayList();
			 for(int i=0;i<vecReportList.size();i++)
			 {
		
			    // This will return the Report Object
			    Report report = (Report)vecReportList.get(i);

			    System.out.println("report="+report.getMenuName());
			    //This method Returns the byte array containing the report layout for the 
			    //given reportID from the report layout repository.
			    //public byte[] getIRLFile(java.lang.String reportId,UserInfo userInfo)
                //@param : reportId - The report id of the requested report layout.
                //@param : userInfo - UserInfo object use to validate the user against the application. 
			    byte reportIRL[]=lm.getIRLFile(report.getReportId(),requestorUserInfo);
			    
			    AdhocReportLayout adhocReportLayout=new AdhocReportLayout();
			    //This method is used for parsing of Nodes.This method can be
			    //used to parse individual report object.
			    adhocReportLayout.parseXml(new ByteArrayInputStream(reportIRL));
			    //For each report the report objects are retrieved from the Intellicus repository
			    //Data Source means Report object used or Query object used.
			    System.out.println("REPORT: "+report.getMenuName()+", DATA SOURCE: "+adhocReportLayout.getDataSource().getName()+", TYPE: "+adhocReportLayout.getDataSource().getType());
			
			    //If the report object list already contains the report object,it will not add report object to it.
				//That means duplicate report objects will not be added to list.
			    if(!reportObjectList.contains(adhocReportLayout.getDataSource().getName()))
			    {
			    	reportObjectList.add(adhocReportLayout.getDataSource().getName());
			    }
			
		     }
			 System.out.println("ReportObject List for category:");
			 for(int j=0;j<reportObjectList.size();j++)
			 {
				System.out.println(reportObjectList.get(j));
			 }	
	      }
	   }
		catch(InterfaceInitException iie)
		{
		System.out.println ("Could not connect to report server::"+iie.getErrorMessage());
		//	iie.printStackTrace();
		}
		catch(LayoutHandlerException lhe){
		System.out.println("ErrorMessage:"+lhe.getExtMessage());	
		}
		catch(AdhocLayoutException ale){
			System.out.println("ErrorMessage:"+ale.getExtMessage());		
		}
	   catch(Exception e)
	   {
			e.printStackTrace();
	   }
			
     }
 }
