/* This sample code is to replace existing query object in the Intellicus repository.
 * This would require user to provide UserInfo to authorize for ReportObjects related Activities.
 * User would require to use following Intellicus jar files for using Intellicus APIs:
 * 1) intellica.jar
 * 2) log4ij.jar
 * 3) xercesImpl.jar
 * 4) xmlParserAPIs.jar
 * Place above jar files in the classpath of your application.
 * These jar files are located at  :  <Install_Path>\Intellicus\APIs
 */

/***
 * DISCLAIMER OF WARRANTY
 * This source code is provided "as is" and without warranties as to performance or merchantability. 
 * 
 * This source code is provided without any express or implied warranties whatsoever
 **/


import com.intellica.client.common.UserInfo; // user info bean 
import com.impetus.intera.reportobjects.QueryObjectColumn; //This is for setting query object column details.
import com.impetus.intera.reportobjects.ReportObjectException;
import com.impetus.intera.reportobjects.ReportObjectManager;//This class is used for Report Object related operations.
import com.impetus.intera.reportobjects.QueryObject;// This class contains all the details about the query object.
import com.impetus.intera.layout.sqleditor.SQLEditor;//This class contains properties and parsing logic for the SQLEDITOR of the report. 
import com.intellica.client.common.Enums;// Has Enums for the constants used
import com.intellica.client.exception.InterfaceInitException;//Thrown as and when there is any error
// in initializing the report Engine interface (REInterface). 

import java.lang.String;
import java.util.ArrayList;
import java.io.FileInputStream;
import java.io.BufferedInputStream;
import java.io.InputStream;

public class ReplaceQueryObject
{
public static void main(String args[]){
		
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
			InputStream is= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																														//with the absolute path of ReportClient.properties.
			
			com.intellica.client.init.ReportClient.init(is);
						
			// Prepare a requestor user info bean object.
			// This user should be present in Intellicus application.
			//Syntax : public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
            //@param userId   - : Id of the User Logged-In.
            //@param password - : Password of the User Logged-In.
            //@param orgId    - : Organization Id from which User Logged-In.
			String	userId	=	"Admin";
			String password = "Admin";
			String organization = "Intellica";
			UserInfo requestorUserInfo	=	new UserInfo(userId,password,organization);
			
			
		    //This is manager class and contains method to get/replace/add/delete a Query object(QO)
			ReportObjectManager reportObjectManager = new ReportObjectManager();
			   	 
			//Query Object with given name, this should exist in the intellicus Repository   	 
			String qOName="TestReplace";
		    
		    //This is to Get java object of query object.
		    //getReportObjectByName method returns report object type object and you would require
		    // to type cast this object with java objet of Query Object class.
		    QueryObject qObject=(QueryObject)reportObjectManager.getReportObjectByName(Enums.IRO.TYPE.QUERY,qOName,requestorUserInfo);
		    
		    
		    //For Adding a new Column
		    
		    //create the coloumn to be added and set its attributes.
		    //public QueryObjectColumn(java.lang.String columnName,java.lang.String caption,java.lang.String width, java.lang.String dataType)			
			QueryObjectColumn qocAdd = new QueryObjectColumn("BANKS.BANKID","BankID","3","NUMBER");
           //Setting other Attributes for the above Column
			//To Set the Alignment for the Column
			// Left Alignment: 0 , Right Alignment: 1
			qocAdd.setAlignment(1);  
			//To set the Data Type CHAR/NUMBER/DATE
			qocAdd.setDataType("NUMBER");
			//Whether to hide this column or not,
			// True : For hidding the Column
			// False: For not hiding.
			// Default value if False.
			qocAdd.setHidden(false);
			//To set the width
			qocAdd.setWidth("20");
			//To set this column in a group
			qocAdd.setGroupLabelCaption("Job");
			//To set the Output Format
			qocAdd.setFormat("Number");
			String hyperLink = "http://www.google.com";
			qocAdd.setHyperlink(hyperLink);
			
			//add this column in the query object
			qObject.addColumn(qocAdd);	
					
			
			//For Removing an Existing Column from the query object.
			boolean removeStatus= qObject.removeColumn("JOB");	
			System.out.println("Column Removed   :   "+removeStatus);
			
			
			//For modifying Attributes of existing Columns
			// This is to change width and other attributes of column Salary in the query object
			String captionName = "Salary";
			
			//This will return array list of all the columns in the query object along with the column details.
			ArrayList list = qObject.getColumnDetails();
			
			//This will iterate all the columns and will change attributes for column Salary.
			for(int i=0;i<list.size();i++)
			{
				QueryObjectColumn qoc=(QueryObjectColumn)list.get(i);
				if(captionName.equals(qoc.getCaption()))
				{
					qoc.setWidth("40");
					qoc.setDataType("NUMBER");
					qoc.setHidden(true);
				}
			}
			
			//This will set all the changes made in the column of the query object.
			qObject.setColumnDetails(list);
								
			//For modifying Query statements.
			//This is to get Object of SQLEditor class fron the query object.
			SQLEditor sqlEditor = qObject.getSqlEditor();
		    
			//Set the new query statement to replace existing Query.
			String ReplaceSql="select BANKS.BANKID from BANKS";
			sqlEditor.setSQL(ReplaceSql,true);
			
			//This will send request to intellicus for replacing report object with the changes made.
			//public void replaceReportObject(ReportObject reportObject,UserInfo userInfo)
			reportObjectManager.replaceReportObject(qObject,requestorUserInfo);		
					
			System.out.println("Query object is replaced"); 
           }//end try
		   catch(InterfaceInitException iie)
		   {
		    System.out.println ("Could not connect to report server::"+iie.getErrorMessage());
		    //	iie.printStackTrace();
		   }
		   catch(ReportObjectException roe){
			System.out.println("Error Message:"+roe.getExtMessage());
		   }
		
		   catch(Exception e)
		   {
			 e.printStackTrace();
		   }	   	 
		    	
		
	}
}		
