//This Java API is used to assign the Access privileges of a Category to the existing Role. 
//User need to provide 
//						- RoleID to which the access rights are to be provided
//						- Category ID of the Category for which the access rights are to be provided
//						- Access Rights that are to be provided to the role. 
//This would also require user to provide UserInfo to authorize for Roles related Activities.

//User would require to use following Intellicus jar files for using Intellicus APIs:
//1) intellica.jar
//2) log4ij.jar
//3) xercesImpl.jar
//4) xmlParserAPIs.jar
//Place above jar files in the classpath of your application.
//These jar files are located at  :  <Install_Path>\Intellicus\APIs

/***
 * DISCLAIMER OF WARRANTY
 * This source code is provided "as is" and without warranties as to performance or merchantability. 
 * 
 * This source code is provided without any express or implied warranties whatsoever
 *
 ***/

// Import Section
// Use intellica jar to import these classes
import com.intellica.client.init.ReportClient; // Has Init Method
import com.intellica.client.common.UserInfo; // Object used to pass in run report
import com.intellica.client.security.AppInfo;
import com.intellica.client.security.EntityAccessRight;
import com.intellica.client.security.EntityInfo;
import com.intellica.client.security.SecurityManager;//Controller class for all security related operations
import com.intellica.client.exception.ISecurityException;// Exception class for all security related operations.
import com.intellica.client.exception.InterfaceInitException;
import com.intellica.client.common.Enums; // Has Enums for the constants used

import java.io.FileInputStream;
import java.io.BufferedInputStream;
import java.io.InputStream;

/* This class 
 * 1)Will get Role Info object for the specified role Id
 * 2)Will Assign category privileges to the specified role for the specified Category
 */
public class AssignCategoryPrivilegesToRole
{

	public static void main(String args[])
	{
		
		try
		{
							
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
			InputStream is= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																														//with the absolute path of ReportClient.properties.
			ReportClient.init(is);									
						
			// Prepare a requestor user info bean object.
			// This user must have Admin rights to perform user management actions
			// such as Add role etc.
			//Syntax public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
            //@param userId   - : Id of the User Logged-In.
            //@param password - : Password of the User Logged-In.
            //@param orgId    - : Organization Id from which User Logged-In.
			String userId = "Admin";
			String password = "Admin";
			String organization = "Intellica";
			UserInfo requestorUserInfo	=	new UserInfo(userId,password,organization);
			
			
			// Create a Security controller class object using its factory 
			// for user/role management related operations
			SecurityManager sMgr=SecurityManager.getInstance();
			
			//RoleID of the Role for which access rights are to be assigned			
			String roleId	="Manager";//role Id to be checked whether exists or not in the Intellicus server
			String orgId    ="hostOrg";		
			String categoryId ="B2996F87-FE41-8D19-6C67-B3C22803DD99";// Id of the category to be assigned to the Role
					
			EntityInfo entityInfo=new EntityInfo(categoryId,"CATEGORY");	
			AppInfo appInfo = new AppInfo(roleId,orgId,"ROLE");
			
			EntityAccessRight ear=new EntityAccessRight();
			
			/*public void setAppInfo(AppInfo appInfo)Parameters:
			 *appInfo - : AppInfo object.
			 * */
			ear.setAppInfo(appInfo);
			/*	access level can have three values possible.
			 *	Deny Access		= 0
			 *  Full Access		= 1
			 *	Partial Access 	= 2
			 *  None Access 	= 3*/
			/**
			 * public void setAccessLevel(int accessLevel)
			 * @param accessLevel : access level can be 0/1/2
			 */	
			ear.setAccessLevel(Enums.SecurityTypes.AccessLevel.FULLACCESS);
			/*public void setAccessRightGrants(java.lang.String grants)Parameters:
			 *grants - : comma separated string specifying grants of access right.*/
			//ear.setAccessRightGrants("0,3");//When partial rights
			/*public void setOpCode(java.lang.String opCode)Parameters:
			 *opCode - the opCode to set*/
			ear.setOpCode("REPLACE");
			/*public void grantEntityPrivileges(EntityInfo entity,
                                  EntityAccessRight entityAccessRight,
                                  UserInfo userInfo)
                           throws ISecurityExceptionThis API allows the user to assign access rights information to a user/role/organization or Everyone on an entity. 

				*Parameters:
				*entity - The entity object.This object must be created by setting entityId and entityType. entityTypes supported are defined in EntityTypeNames class.
				*entityAccessRight - The entityAccessRight object. This object should contain the AppInfo object with the credentials of the user to which grants are to be assigned and access level as defined in Enums.SecurityTypes.AccessLevel
				*userInfo - The userInfo object for authorization. 
				*Throws: 
				*ISecurityException: - If the request cannot be performed successfully. This happens - 1.if connection can't be established with the engine or 2.if read or write operation cant be performed from or to the engine. 3.If some error has occured while executing the request on the engine. 4.If the response xml obtained from server cannot be parsed 
				*ISecurityException
			 * */
			sMgr.grantEntityPrivileges(entityInfo, ear, requestorUserInfo);
			
			}	
		    catch(InterfaceInitException iie)
		    {
		        System.out.println ("Could not connect to report server::"+iie.getErrorMessage());
		        //	iie.printStackTrace();
		    }
			catch(ISecurityException e)
			{
				// Rootcause message sent by the report server 
				// for Assigning category privileges to the specified role 
				e.getExtMessage();
			}
											
		catch(Exception e)
		{
			e.printStackTrace();
		}
	}  // End of main function
}		
