//This Java API is used to create a Report Schedule that is delivered daily through all delivery Options.
//This would require user to set the task and the schedule according to which , the task should be done.
//This would require the user to provide UserInfo to authorize for "Schedule Report"

//User would require to use following Intellicus jar files for using Intellicus APIs:
//1) intellica.jar
//2) log4ij.jar
//3) xercesImpl.jar
//4) xmlParserAPIs.jar
//Place above jar files in the classpath of your application.
//These jar files are located at  :  <Install_Path>\Intellicus\APIs



/***
 * DISCLAIMER OF WARRANTY
 * This source code is provided "as is" and without warranties as to performance or merchantability. 
 * 
 * This source code is provided without any express or implied warranties whatsoever
 *
**/
 
 
// This program 
// 1) Creates a userinfo Object of current logged in User.
// 2) Sets business parameters required to execute the report.
// 3) creates a report delivery task for all Delivery Options.
// 4) creates a recurring schedule which will run Daily.
// 5) creates a ScheduleJob using 3) and 4).

// Import Section
// Use intellica jar to import these classes


import java.util.HashMap;
import java.util.Hashtable;
import java.io.FileInputStream;
import java.io.BufferedInputStream;
import java.io.InputStream;

import com.intellica.client.common.Enums;
import com.intellica.client.common.InteraConstants;// Constants used
import com.intellica.client.common.UserInfo;// user info bean
import com.intellica.client.exception.InterfaceInitException;//Thrown as and when there is any error
															// in initializing the report Engine interface (REInterface). 

import com.intellica.client.exception.SchedulerException;
import com.intellica.client.init.ReportClient;// Has Init Method
import com.intellica.schd.client.EMailProperty;
import com.intellica.schd.client.FTPProperty;
import com.intellica.schd.client.PrintProperty;
import com.intellica.schd.client.PublishProperty;
import com.intellica.schd.client.Schedule;
import com.intellica.schd.client.ScheduleJob;
import com.intellica.schd.client.SchedulerManager;
import com.intellica.schd.client.Task;



public class  CreateDailyReportScheduleWithAllDeliveryOptions

{
		public static void main(String str[]){
		try{
			
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
			InputStream is= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																														//with the absolute path of ReportClient.properties.
			ReportClient.init(is);
		
			
			// Prepare a requestor user info bean object.
			// This user should be present in Intellicus application.
			UserInfo userInfo	=	new UserInfo("Admin","Admin","Intellica");
					
			
			// Create a Scheduler Manager class object 
			// for scheduler management related operations
			SchedulerManager schdMgr	=	new SchedulerManager();
			
			
			/* THIS IS TO ADD A NEW TASK
			   This object holds an instance of Task class.  
			   This Task is used by the ScheduledJob
			*/ 	
				//create new instance of task with given task name. This constructor call takes care
				//of initializing task Id as well.
				Task  task	=	new Task();  
							
				// Set the Task name, This line may not require for dedicated tasks
				task.setBatchName("Shared_Task1");                               

				//set the report id that is to be scheduled.	
				String reportId	= "BFB7ADDF-09BD-D6EF-569A-A7E4500412AE";
				task.setReportID(reportId);
				
				// Set report output format for the delivery.  
				// This line is optional, if PDF is the required format.
				task.setReportFormat(InteraConstants.ReportFormats.PDF);
						
			 // Set Business Parameters or hidden parameters for this user.
			 // Note that these will be persisted with the scheduled Job for ever,
			 // and will be unaffected to changes in other parts of the system.
			 // For Ex: If a user is suspended, or role is changed then Super User should take separate care to 
			 // delete old schedules defined using previous role or other values.
			 // If business parameters(like VIEWER_ROLE) changes in the application then schedule will run 
			 // with the VIEWER_ROLE value set at the time of scheduleJob creation.
				HashMap 	inputParam	=	new HashMap();
				inputParam.put("VIEWER_ROLE","1");
				inputParam.put("PE_ID1","1000");
				
				//Set Business Parameters into Parameter table 
			 	Hashtable userMapTable	=	new Hashtable();
			 	userMapTable.put(InteraConstants.REPORT_PARAMS,inputParam);
			 	
			 	//set UserParam HasMap in task
				task.setUserParam(userMapTable);
			
						
				//set whether the task is public or private
				task.setIsPublic(false);
								
				//set whether the task is shared or dedicated
     			task.setIsShared(false);
				
				//task.setPublish(true);
				
				//set Delivery operation type 
				task.setDeliveryOperationType(com.intellica.client.common.Enums.Batch.DispatchOperationTypes.PUBLISH);
				task.setDeliveryOperationType(com.intellica.client.common.Enums.Batch.DispatchOperationTypes.EMAIL);
				task.setDeliveryOperationType(com.intellica.client.common.Enums.Batch.DispatchOperationTypes.PRINT);
				
				task.setDeliveryOperationType(com.intellica.client.common.Enums.Batch.DispatchOperationTypes.FTP);
 				
				//-----------------Upload Report in Shared Folder-------------------------	
				
				// get FTPProperty object for setting Email attributes of the task
				//This class holds the system parameters of FTP operation type. 
				//It acts as a data container for the operation type FTP. 
				//Syntax : public FTPProperty()
				FTPProperty ftpProp = task.getFTPProperty();
				
				//Set the Upload type to FTP or SHAREDFOLDER 
				//It takes String constant : 
				//	Enums.Batch.UploadType.SHAREDFOLDER
				//	Enums.Batch.UploadType.FTP
				ftpProp.setUploadType(Enums.Batch.UploadType.SHAREDFOLDER);
				 
				//Set the folder name where Report Output is to be placed
				ftpProp.setFolderName("E:\\Intellicus");
				
				//Set the name of the Output File
				ftpProp.setFileName("SharedTask");
				 	
				
			//-----------------Print Report-------------------------	
				
				//This class holds PrintProperty for Task. 
				//All the variables are used for making a print request.
				//Syntax : public PrintProperty()
				PrintProperty printProp = task.getPrintProperty();
				
				//Number of copies to be printed
				printProp.setPrintCopies(1);
				
				//Printer name that is used for printing
				printProp.setPrinterName("Microsoft XPS Document Writer");
				
				//Set the number of pages to be printed
				printProp.setPrintPageRange("All");
				
				
				//-----------------Publish Report-------------------------	
				
				//get PublishProperty object for setting publish attributes fro the task
				//This class is used for specifying the validation period of a given report. 
				//The default value is the infinite expiry set by publishValidUptoFixedDate 
				//variable having 0 value
				//Default Construtor : Creates a Publish Property Object with Infinite Expiry
				PublishProperty publishProp = task.getPublishProperty();
				
				//setter method for saveFileName member variable. 
				//Syntax : public void setSaveFileName(java.lang.String saveFileName)
				//@param saveFileName - takes String value
				publishProp.setSaveFileName("Shared_Publish1");

				//setter method for isPublic member variable.
				//Syntax : public void setIsPublic(boolean isPublic) 
				//@param isPublic - takes boolean value.
				publishProp.setIsPublic(true);	//True : Set the Published Report as Public

				//setter method for periodType member variable.
				//This actually sets till what time the published report should be valid i.e.
				//Enums.Batch.PeriodType.ENDPERIOD : valid upto end of Day, Hour, Month, Week, Year.
				//For ENDPERIOD, call setEndPeriod to set the value to Day, Hour, Month, Week, Year.
				//Enums.Batch.PeriodType.EXPIRYDATE : valid upto a particular date
				//For EXPIRYDATE, call setPublishValidUptoFixedDate to set the end Date.
				//Enums.Batch.PeriodType.INTERVALPERIOD : valid upto fixed interval 
				//For INTERVALPERIOD, call setIntervalValue and then set the value for Interval Period.
				//Syntax : public void setPeriodType(int periodType) 
				//@param periodType - takes int value.
				publishProp.setPeriodType(Enums.Batch.PeriodType.ENDPERIOD);
			
				//setter method for endPeriod member variable when Period Type is set to ENDPERIOD
				//It sets the endPeriod value to either Hour, Day , Week , Month, or Year. 
				//Syntax : public void setEndPeriod(java.lang.String endPeriod) 
				//@param endPeriod - takes String value
				publishProp.setEndPeriod(com.intellica.client.common.Enums.Batch.EndPeriod.YEAR);
				
				
				//-----------------E-mail Report------------------------------	
				
				//get EmailProperty object for setting Email attributes of the task.
				//This class holds the system parameters of EMail operation type. 
				//It acts as a data container for the operation type Email. 
				//The default value for all the parameters is the empty string.
				//Default Constructor : Creates a EMail Property Object with default empty String 
				//Syntax : public EMailProperty()
				EMailProperty  eMailProp	=	task.getEMailProperty();
				
				//Attach the Report Output to the mail.
				//Syntax : public void setMailAttach(boolean isMailAttach)
				//@param isMailAttach - for EmailProperty.
				//True indicates Report Output send as an Attachment through E-mail.  
				//False indicates Report Output send as a Link through Email. 
				eMailProp.setMailAttach(true);
				
				// Set the Email to this address. For multiple address separate them by (,) or (;)
				//Syntax : public void setMailTO(java.lang.String mailTO) 
				//@param mailTO - for the EmailProperty.
				eMailProp.setMailTO("HostUser@OrgUser.com");
				
				// Set the subject of mail
				//public void setMailSUB(java.lang.String mailSUB) 
				//@param mailSUB - for EmailProperty.
				eMailProp.setMailSUB("Mail Subject goes here............"); 		
				
				// Set the Message of E-mail
				// Email message can be set in the text file(\ReportEngine\config\attachemailmessage.txt)
				// This text file can have HTML messages also.(HTML tags needs to be strictly matching)
				// comment out the eMailProp.setMailMSG call for server to take message from attachemailmessage.txt
				eMailProp.setMailMSG("Dear User , Please find  <%Report_Name%>  attached");
			    
				//getter method for mailCC member variable. returns mailCC value for EmailProperty.
				//Syntax : public java.lang.String getMailCC() 
				eMailProp.setMailCC("HostUser@OrgUser.com");
				
				//getter method for mailBCC member variable. returns mailBCC value EmailProperty.
				//Syntax :  public java.lang.String getMailBCC()
				eMailProp.setMailBCC("HostUser@OrgUser.com");
		
				
				/* This is to add a new schedule
				  This object holds an instance of Schedule class.  
				  This Schedule is used by the ScheduledJob
				  
				*/ 	
				//create new instance of schedule. This constructor call takes care
				//of initializing schedule Id as well.			
				Schedule schedule	=	new Schedule();
		
				
				// Set the schedule name, This line may not require 
				schedule.setScheduleName("Shared_Schedule8");
								
				//Set Frequency type as Daily
				//Other values for Freequency Type could be 
				//	Enums.Schedule.FrequencyTypes.DAILY
				//	Enums.Schedule.FrequencyTypes.MONTHLY
				//	Enums.Schedule.FrequencyTypes.WEEKLY
				schedule.setFrequencyType(Enums.Schedule.FrequencyTypes.DAILY);
				
				//The schedule starts on this date 
				schedule.setStartDate("01/07/2008");
				
				//The schedule ends on this date (Set it blank for schedule to repeat infinitely)
				schedule.setEndDate("01/08/2008");
				
				//Set time type as ONCE
				//Other values for Time Type could be :
				//	Enums.Schedule.TimeTypes.ONCE
				//	Enums.Schedule.TimeTypes.REPEAT
				schedule.setTimeType(Enums.Schedule.TimeTypes.ONCE);
				
				//Execution Time for the Schedule to run the task
				String executionTime = "12:57:10";
				//Set execution time on the scheduled day in HH:Mi:SS format
				schedule.setOnceTime(executionTime);
				
				//To share the Schedule
				//	true : allowing more than one task to share the this schedule
				//	false : For dedicated Shedules in which this schedule can only be associated with 
				// 			only one Schedule.
				schedule.setIsShared(false);
			
				/* create a SCHEDULEDJOB with the above ReportDeliveryTask and Schedulefrequency.
			  	ScheduledJob object takes instance of task and schedule objects.*/
				//This class holds the Job specific details. 
				//It contains the Task and Schedule objects that can be used for scheduling a job. 
				//The constructors can be used for creating a Task as well as a Schedule in one constructor call of this class. 
				//Syntax : public ScheduleJob(Task dedicatedTask, Schedule dedicatedSchedule) 
				//Overloaded Construtor: Creates a ScheduleJob Object
                //@param dedicatedTask - Task class object
                //@param dedicatedSchedule - Schedule object
				ScheduleJob	schdJob		=	new ScheduleJob(task,schedule);
				
                // This name can be used to display in list
				schdJob.setJobName("Shared_Job8"); 
			
				//set whether the schedule job is public or private
                schdJob.setIsPublic(false);

                //set whether the schedule job is shared or dedicated
                schdJob.setIsShared(false);
				
								
				// Set support staff mail id for sending mail when schedule executed successfully.
				schdJob.setOnSuccessMailTo("successId@HostOrg.com");
				
				// Set support staff mail id for sending mail when schedule failed to execute.
				schdJob.setOnFailureMailTo("failureId@HostOrg.com");	
								
						
				// This will add the ScheduleJob to Intellicus Repository	
				schdMgr.addScheduleJob(schdJob,userInfo);
		}
		catch(InterfaceInitException iie)
		{
			iie.printStackTrace();
		}
		catch(SchedulerException se)
		{
			se.printStackTrace();
		}
		catch(Exception e){
			e.printStackTrace();
		}
	}
}
