//This Java API is used to create a Report Schedule that is delivered daily through E-mail.
//This would require user to set the task and the schedule according to which , the task should be done.
//This would require the user to provide UserInfo to authorize for "Schedule Report"

//User would require to use following Intellicus jar files for using Intellicus APIs:
//1) intellica.jar
//2) log4ij.jar
//3) xercesImpl.jar
//4) xmlParserAPIs.jar
//Place above jar files in the classpath of your application.
//These jar files are located at  :  <Install_Path>\Intellicus\APIs

/***
 * DISCLAIMER OF WARRANTY
 * This source code is provided "as is" and without warranties as to performance or merchantability. 
 * 
 * This source code is provided without any express or implied warranties whatsoever
 *
**/
 
 
// This program 
// 1) Creates a userinfo Object of current logged in User.
// 2) Sets business parameters required to execute the report.
// 3) creates a report delivery task for EMailing the report.
// 4) creates a recurring schedule which will run Daily.
// 5) creates a ScheduleJob using 3) and 4).
//
// Import Section
// Use intellica jar to import these classes

import java.util.HashMap;
import java.util.Hashtable;
import java.io.FileInputStream;
import java.io.BufferedInputStream;
import java.io.InputStream;

import com.intellica.client.common.Enums;
import com.intellica.client.common.InteraConstants;// Constants used
import com.intellica.client.common.UserInfo;// user info bean
import com.intellica.client.exception.InterfaceInitException;//Thrown as and when there is any error in initializing the report Engine interface (REInterface).
import com.intellica.client.exception.SchedulerException;
import com.intellica.client.init.ReportClient;// Has Init Method
import com.intellica.schd.client.EMailProperty;
import com.intellica.schd.client.Schedule;
import com.intellica.schd.client.ScheduleJob;
import com.intellica.schd.client.SchedulerManager;
import com.intellica.schd.client.Task;

public class  CreateDailyReportScheduleWithEmailDelivery
{
		public static void main(String str[]){
		try{
			
			
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
			InputStream is= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																														//with the absolute path of ReportClient.properties.
			ReportClient.init(is);
			   
			// Prepare a requestor user info bean object.
			// This user should be present in Intellicus application.
			UserInfo 		 userInfo	=	new UserInfo("Admin","Admin","Intellica");
					
			
			// Create a Scheduler Manager class object 
			// for scheduler management related operations
			SchedulerManager schdMgr	=	new SchedulerManager();
			
			
						
			/* THIS IS TO ADD A NEW TASK
			   This object holds an instance of Task class.  
			   This Task is used by the ScheduledJob
			  
			*/ 	
				//create new instance of task with given task name. This constructor call takes care
				//of initializing task Id as well.
				Task  task		=	new Task();  
							
				// Set the Task name, This line may not require for dedicated tasks
				task.setBatchName("Task_Daily");                               

				//set the report id that is to be scheduled.	
				String reportId	= "93F21A40-01DD-DFFC-C874-A7E30A27A127";
				task.setReportID(reportId);
				
				// Set report output format for the delivery.  
				// This line is optional, if PDF is the required format.
				task.setReportFormat(InteraConstants.ReportFormats.PDF);
						
			 // Set Business Parameters or hidden parameters for this user.
			 // Note that these will be persisted with the scheduled Job for ever,
			 // and will be unaffected to changes in other parts of the system.
			 // For Ex: If a user is suspended, or role is changed then Super User should take separate care to 
			 // delete old schedules defined using previous role or other values.
			 // If business parameters(like VIEWER_ROLE) changes in the application then schedule will run 
			 // with the VIEWER_ROLE value set at the time of scheduleJob creation.
				HashMap 	inputParam	=	new HashMap();
				inputParam.put("VIEWER_ROLE","1");
				inputParam.put("PE_ID1","1000");
				
				//Set Business Parameters into Parameter table 
			 	Hashtable userMapTable	=	new Hashtable();
			 	userMapTable.put(InteraConstants.REPORT_PARAMS,inputParam);
			 	
			 	//set UserParam HasMap in task
				task.setUserParam(userMapTable);
			
						
				//set whether the task is public or private
				task.setIsPublic(false);
								
				//set whether the task is shared or dedicated
     			task.setIsShared(false);
				
																
				//set Delivery operation type to Email
				task.setDeliveryOperationType(com.intellica.client.common.Enums.Batch.DispatchOperationTypes.EMAIL);
							
				// get EmailProperty object for setting Email attributes
				EMailProperty  eMailProp	=	task.getEMailProperty();
				
				//We need the report output to be attached to the mail.
				eMailProp.setMailAttach(true);
				
				// Set the Email to this address. For multiple address separate them by , or ;
				eMailProp.setMailTO("HostUser@HostOrg.com");
				
				// Set the subject of mail
				eMailProp.setMailSUB("Mail Subject goes here"); 		
				
				// Set the Message of mail
				
				// This can be used to set Email message.
				// Email message can be set in the text file(\ReportEngine\config\attachemailmessage.txt)
				// This text file can have HTML messages also.(HTML tags needs to be strictly matching)
				// comment out the eMailProp.setMailMSG call for server to take message from attachemailmessage.txt
				eMailProp.setMailMSG("Dear User, Please find  <%Report_Name%>  attached");
			    // If need to CC mail
				eMailProp.setMailCC("HostUser@HostOrg.com");
				// If need to BCC mail
				eMailProp.setMailBCC("HostUser@HostOrg.com");
		
				/* This is to add a new schedule
				  This object holds an instance of Schedule class.  
				  This Schedule is used by the ScheduledJob
				  
				*/ 	
				//create new instance of schedule. This constructor call takes care
				//of initializing schedule Id as well.			
				Schedule schedule	=	new Schedule();
				
				// Set the schedule name, This line may not require 
				schedule.setScheduleName("Schedule_Daily");
								
				//Set Frequency type as Daily
				schedule.setFrequencyType(Enums.Schedule.FrequencyTypes.DAILY);
				
				//The schedule starts on this date 
				schedule.setStartDate("02/16/2006");
				//The schedule ends on this date (Set it blank for schedule to repeat infinitely)
				schedule.setEndDate("06/04/2006");
				
				//Set time type as ONCE
				schedule.setTimeType(Enums.Schedule.TimeTypes.ONCE);
				
				//Set execution time on the scheduled day in HH:Mi:SS format
				schedule.setOnceTime("16:05:10");
				//Set is shared
				schedule.setIsShared(false);
			
			 /* create a SCHEDULEDJOB with the above ReportDeliveryTask and Schedulefrequency.
			  ScheduledJob object takes instance of task and schedule objects.*/

				ScheduleJob	schdJob		=	new ScheduleJob(task,schedule);
				
                // This name can be used to display in list
				schdJob.setJobName("Job_Daily"); 
			
				 //set whether the schedule job is public or private
                 schdJob.setIsPublic(false);

                //set whether the schedule job is shared or dedicated
                schdJob.setIsShared(false);
				
								
				// Set support staff mail id for sending mail when schedule executed successfully.
				schdJob.setOnSuccessMailTo("successId@HostOrg.com.com");
				
				// Set support staff mail id for sending mail when schedule failed to execute.
				schdJob.setOnFailureMailTo("failureId@HostOrg.com.com");	
								
						
				// This will add the ScheduleJob to Intellicus Repository	
				schdMgr.addScheduleJob(schdJob,userInfo);
		}
		catch(InterfaceInitException iie)
		{
			iie.printStackTrace();
		}
		catch(SchedulerException se)
		{
			se.printStackTrace();
		}
		catch(Exception e)
		{
			e.printStackTrace();
		}
	}
}
