//User would require to use following Intellicus jar files for using Intellicus APIs:
//1) intellica.jar
//2) log4ij.jar
//3) xercesImpl.jar
//4) xmlParserAPIs.jar
//Place above jar files in the classpath of your application.
//These jar files are located at  :  <Install_Path>\Intellicus\APIs


/***
 * DISCLAIMER OF WARRANTY
 * This source code is provided "as is" and without warranties as to performance or merchantability. 
 * 
 * This source code is provided without any express or implied warranties whatsoever
 *
**/
 
 
// This program 
// 1) Creates a userinfo Object of current logged in User.
// 2) Returns list of report schedules for a selected report.
// 3) Report schedule list can be filtered for ReportId and UserId

// Import Section
// Use intellica jar to import these classes

import com.intellica.client.common.UserInfo; // user info bean 
import com.intellica.client.init.ReportClient; // Has Init Method
import com.intellica.schd.client.*;  //Package containing all classes for scheduling
import com.intellica.client.common.Filter; // Filter object for setting filter options
import com.intellica.client.common.Enums; // Has Enums for the constants used
import com.intellica.client.exception.InterfaceInitException;//Thrown as and when there is any error in initializing the report Engine interface (REInterface). 
import com.intellica.client.exception.SchedulerException;

import java.util.ArrayList; // Array list
import java.io.FileInputStream;
import java.io.BufferedInputStream;
import java.io.InputStream;

public class  GetScheduleJobList
{
		public static void main(String str[]){
		try{
			
			
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
			InputStream is= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																														//with the absolute path of ReportClient.properties.
			ReportClient.init(is);
		
			
			// Prepare a requestor user info bean object.
			// This user should be present in Intellicus application.
			//Syntax : public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
	        //@param userId   - : Id of the User Logged-In.
	        //@param password - : Password of the User Logged-In.
	        //@param orgId    - : Organization Id from which User Logged-In.
			String	userId	=	"Admin";
			String password = "Admin";
			String organization = "Intellica";
			UserInfo userInfo =	new UserInfo(userId,password,organization);
			
			// Create a Scheduler Manager class object 
			// for scheduler management related operations
			SchedulerManager schdMgr	=	new SchedulerManager();
			
			
		   // Create a Filter class Object
		   Filter filterObj = new Filter();
		   
		   // set filter for private schedule jobs
		   filterObj.setFilterField(Enums.Filters.ScheduledJob.ISPUBLIC,"false");
		  
		   // set filter for dedicated(Non-shared) schedule jobs
		   filterObj.setFilterField(Enums.Filters.ScheduledJob.ISSHARED,"false");
		  
		   //Set the ReportId filter for getting all report schedules for this Report
		   //If this filter is not set then report schedules of all the Reports will be listed.
		   String reportId	= "93F21A40-01DD-DFFC-C874-A7E30A27A127";
	       filterObj.setFilterField(Enums.Filters.ScheduledJob.REPORTID,reportId);
		   
		   //Set the UserId filter for getting list of report schedules of a particular user
		   //If this filter is not set then report schedules of all the users will be listed(for super admin user).
		   //If this filter is not set then report schedules of his own will be listed(for normal user).
		   
	       String userID	= "HostUser";
		   filterObj.setFilterField(Enums.Filters.ScheduledJob.USERID,userID);
		   
		   
		   //Set the orgId filter for getting list of report schedules of a user of this organization only
		   //If this filter is not set then orgId of the requestor user will be used).
		    String orgId	= "HostOrg";
		    filterObj.setFilterField(Enums.Filters.ScheduledJob.ORGID,orgId);
		   		
			
			// This will return array of Scheduled Jobs list from the Intellicus Repository	
			ArrayList jobList = schdMgr.getScheduledJobList(filterObj,userInfo);
	
			// This will list all report schedules 
			for(int i=0; i<jobList.size(); i++){
				ScheduleJob reportSchedule	= (ScheduleJob) jobList.get(i);
				
				// To get Owner of the report schedule
				String ownerId		=	reportSchedule.getOwnerID();
			
				// To get last run time of the report schedule
				String lastRunTime	=	reportSchedule.getLastRunOn();			
				// To get Next run time of the report schedule
				String nextRunTime	=	reportSchedule.getNextScheduleOn();
				
															
				System.out.println ("Schedule Job Id: "+reportSchedule.getJobID());	
				System.out.println ("Schedule created by: "+ownerId);
				System.out.println ("Last Run Time: "+lastRunTime);	
				System.out.println ("Next Run Time: "+nextRunTime);
				
			}				
			
		}
		catch(InterfaceInitException iie)
		{
			iie.printStackTrace();
		}
		catch(SchedulerException se)
		{
			se.printStackTrace();
		}
		catch(Exception e)
		{
			e.printStackTrace();
		}
	}
}
 