// This program 
// 1) creates a new user with this given userId, 
// 2) Maps the new user with the same names App ID when authentication is done by call back method or host application.

//User would require to use following Intellicus jar files for using Intellicus APIs:
//1) intellica.jar
//2) log4ij.jar
//3) xercesImpl.jar
//4) xmlParserAPIs.jar
//Place above jar files in the classpath of your application.
//These jar files are located at  :  <Install_Path>\Intellicus\APIs

/***
 * DISCLAIMER OF WARRANTY
 * This source code is provided "as is" and without warranties as to performance or merchantability. 
 * 
 * This source code is provided without any express or implied warranties whatsoever
 *
 **/


// Import Section
import java.io.FileInputStream;
import java.io.BufferedInputStream;
import java.io.InputStream;

// Use intellica jar to import these classes

import com.intellica.client.init.ReportClient; // Has Init Method
import com.intellica.client.common.UserInfo; // Object used to pass in run report
import com.intellica.client.security.SecurityManager;// Has user management methods
import com.intellica.client.exception.ISecurityException;// For exceptions during user management
import com.intellica.client.exception.InterfaceInitException;//Thrown as and when there is any error
                                                             // in initializing the report Engine interface (REInterface). 

//This class adds a new user to the existing organization with a given user id and also do mapping of application user to Intellicus user when
//authentication is done by call back authentication method or host application..
public class AddUserWithBlankSpaceInUserName
{

	public static void main(String args[])
	{
		
		try
		{
						
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
			InputStream is= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																														//with the absolute path of ReportClient.properties.
			ReportClient.init(is);
			
			// Prepare a requestor user info bean object.
			// This user must have Admin rights to perform user management actions
			// such as create user
			// This user should be present in Intellicus application.
			//Syntax public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
            //@param userId   - : Id of the User Logged-In.
            //@param password - : Password of the User Logged-In.
            //@param orgId    - : Organization Id from which User Logged-In.
			String adminUserId = "Admin";
			String adminPassword = "Admin";
			String adminOrganization = "Intellica";
			UserInfo requestorUserInfo	=	new UserInfo(adminUserId,adminPassword,adminOrganization);
		
			// Create a SecurityManager class object 
		    // for getting the controller information for all Administration related operations
			//public getInstance method to access the static instance of SecurityManager object
			//Syntax public static SecurityManager getInstance()
			SecurityManager sMgr =SecurityManager.getInstance();
			
			// prepare new user info			
			String userId="MNormal User";// id having blank space in user id
			String password="MNormal";
			String organization="Test";
			
			// Create a User Info Object for adding a new user
			UserInfo addUserInfo=new UserInfo(userId,password,organization);
			
			// set this user as Admin User for his organization.
			//addUserInfo.setAdmin(true);
			
			//Set User Password as Blank when authentication performed by Host application.
			//addUserInfo.setBlankPassword(true);
						 
			//To Add new user.
			//Syntax: public void addUser(UserInfo newUserInfo,UserInfo userInfo)             
            //@param newUserInfo -  The new user or target user details 
            //@param userInfo    -  The current user details 
			sMgr.addUser(addUserInfo,requestorUserInfo);
			
			
				//  Map intellicus user to the host application	user
				//  map User (Aplplication user id string, 
				//                         user info of intellicus user to be mapped 
				//                                 , requestor admin user)
				//  assuming we are mapping chris1 to chris1
				//@param requestorUserInfo - The current user details who is providing access rights 
				//					         to the specified user.
			 
				//@param addUserInfo - The user info of the user that is to be added.
				sMgr.mapAppIdToUser(userId,addUserInfo,requestorUserInfo);	
						
			
			}
			 
			catch(InterfaceInitException iie)
			{
			System.out.println ("Could not connect to report server::"+iie.getExtMessage());
			//	iie.printStackTrace();
			}
			catch(ISecurityException ise)
			{
				System.out.println ("Failed to add a new user::"+ise.getExtMessage());
				ise.printStackTrace();
			}
			catch(Exception e)
			{
				e.printStackTrace();
			}
		
	}
	
	
	
}		
