//This Java API is used to set the Report Access Privileges for a particular user
//The user would require to provide its identity i.e. user Info and the Report for 
//which the access rights are to be given.

//User would require to use following Intellicus jar files for using Intellicus APIs:
//1) intellica.jar
//2) log4ij.jar
//3) xercesImpl.jar
//4) xmlParserAPIs.jar
//Place above jar files in the classpath of your application.
//These jar files are located at  :  <Install_Path>\Intellicus\APIs

/***
 * DISCLAIMER OF WARRANTY
 * This source code is provided "as is" and without warranties as to performance or merchantability. 
 * 
 * This source code is provided without any express or implied warranties whatsoever
 *
**/


import com.intellica.client.common.Enums;
import com.intellica.client.common.UserInfo;// Object used to pass in run report
import com.intellica.client.exception.ISecurityException;// Exception class for all security related operations.
import com.intellica.client.exception.InterfaceInitException;
import com.intellica.client.init.ReportClient;// Has Init Method
import com.intellica.client.security.AppInfo;
import com.intellica.client.security.EntityAccessRight;
import com.intellica.client.security.EntityInfo;
import com.intellica.client.security.SecurityManager;//Controller class for all security related operations  

import java.io.FileInputStream;
import java.io.BufferedInputStream;
import java.io.InputStream;

//This class is used to assign the Access privileges for a Report to the User. 
//The user would require to provide its identity i.e. user Info , 
//info of the User whose access privileges are to be set, and the 
//ReportID for which the access rights are to be given.

public class AssignReportPrivilegesToUser 
{
	public static void main(String args[])
	{
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
			InputStream is= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																														//with the absolute path of ReportClient.properties.
			ReportClient.init(is);
			
			// Prepare a requestor user info bean object.
			// This user should be present in Intellicus application.
			//Syntax public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
            //@param userId   - : Id of the User Logged-In.
            //@param password - : Password of the User Logged-In.
            //@param orgId    - : Organization Id from which User Logged-In.
			String adminId = "Admin";
			String adminPassword = "Admin";
			String adminOrganization = "Intellica";
			String userId="testUser";
			String userOrganisation="hostOrg";
			
			UserInfo adminUserInfo	=	new UserInfo(adminId,adminPassword,adminOrganization);
			
			//	Create a Security controller class object using its factory 
			// for user management related operations
			//public getInstance method to access the static instance of SecurityManager object
			//Syntax public static SecurityManager getInstance()
			SecurityManager sMgr =SecurityManager.getInstance();
			String reportId="638CB7A6-F504-0ECD-008F-10B25253DCA8";
            
            EntityInfo entityInfo=new EntityInfo(reportId,"REPORT");	
			AppInfo appInfo = new AppInfo(userId,userOrganisation,"USER");
			
			EntityAccessRight ear=new EntityAccessRight();
			
			/*public void setAppInfo(AppInfo appInfo)Parameters:
			 *appInfo - : AppInfo object.
			 * */
			ear.setAppInfo(appInfo);
			/*	access level can have three values possible.
			 *	Deny Access		= 0
			 *  Full Access		= 1
			 *	Partial Access 	= 2
			 *  None Access 	= 3*/
			/**
			 * public void setAccessLevel(int accessLevel)
			 * @param accessLevel : access level can be 0/1/2
			 */	
			ear.setAccessLevel(Enums.SecurityTypes.AccessLevel.FULLACCESS);
			/*public void setAccessRightGrants(java.lang.String grants)Parameters:
			 *grants - : comma separated string specifying grants of access right.*/
			//ear.setAccessRightGrants("0,3");//When partial rights
			/*public void setOpCode(java.lang.String opCode)Parameters:
			 *opCode - the opCode to set*/
			ear.setOpCode("REPLACE");
			/*public void grantEntityPrivileges(EntityInfo entity,
                                  EntityAccessRight entityAccessRight,
                                  UserInfo userInfo)
                           throws ISecurityExceptionThis API allows the user to assign access rights information to a user/role/organization or Everyone on an entity. 

				*Parameters:
				*entity - The entity object.This object must be created by setting entityId and entityType. entityTypes supported are defined in EntityTypeNames class.
				*entityAccessRight - The entityAccessRight object. This object should contain the AppInfo object with the credentials of the user to which grants are to be assigned and access level as defined in Enums.SecurityTypes.AccessLevel
				*userInfo - The userInfo object for authorization. 
				*Throws: 
				*ISecurityException: - If the request cannot be performed successfully. This happens - 1.if connection can't be established with the engine or 2.if read or write operation cant be performed from or to the engine. 3.If some error has occured while executing the request on the engine. 4.If the response xml obtained from server cannot be parsed 
				*ISecurityException
			 * */
			sMgr.grantEntityPrivileges(entityInfo, ear, adminUserInfo);	
		}
		catch(InterfaceInitException iie)
		{
		    System.out.println ("Could not connect to report server::");
			iie.printStackTrace();
		}
		catch(ISecurityException ise){
			System.out.println("Error Message: "+ise.getExtMessage());
			
		}
		catch(Exception e)
		{
			e.printStackTrace();
		}

	}
}
