// This program is to Assign a specified role to the application user 
//The requestor user would require to provide its identity i.e. user Info to get authorize for providing role
//rights to the particular user

//User would require to use following Intellicus jar files for using Intellicus APIs:
//1) intellica.jar
//2) log4ij.jar
//3) xercesImpl.jar
//4) xmlParserAPIs.jar
//Place above jar files in the classpath of your application.
//These jar files are located at  :  <Install_Path>\Intellicus\APIs

/***
 * DISCLAIMER OF WARRANTY
 * This source code is provided "as is" and without warranties as to performance or merchantability. 
 * 
 * This source code is provided without any express or implied warranties whatsoever
 *
 ***/


// Import Section
// Use intellica jar to import these classes
import com.intellica.client.init.ReportClient; // Has Init Method
import com.intellica.client.common.UserInfo; // Object used to pass in run report
import com.intellica.client.security.SecurityManager;//Controller class for all security related operations  
import com.intellica.client.security.RoleInfo; // Has information about a role in the application
import com.intellica.client.exception.ISecurityException;// Exception class for all security related operations.
import com.intellica.client.exception.InterfaceInitException;//Thrown as and when there is any error
															// in initializing the report Engine interface (REInterface). 
import java.io.FileInputStream;
import java.io.BufferedInputStream;
import java.io.InputStream;

//This class assigns a role to the application user.
public class AssignRoleToUser
{

	public static void main(String args[])
	{
		
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
			InputStream is= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																														//with the absolute path of ReportClient.properties.
			ReportClient.init(is);
			
								
			// Prepare a requestor user info bean object.
			// This user must have Admin rights to perform user management actions
			// such as Add role etc.
			//Syntax public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
            //@param userId   - : Id of the User Logged-In.
            //@param password - : Password of the User Logged-In.
            //@param orgId    - : Organization Id from which User Logged-In.
			String adminUserId = "Admin";
			String adminPassword = "Admin";
			String adminOrganization = "Intellica";
			UserInfo 	 requestorUserInfo	=	new UserInfo(adminUserId,adminPassword,adminOrganization);
			
		
			String roleId	="Manager"; // Id of the role to be Assigned
			String userId	="MNormal"; // Id of the application user
			String orgId    ="TestOrg";//Id of the organization to which the application user belongs
			// Create a Security controller class object using its factory 
			// for user/role management related operations
			//public getInstance method to access the static instance of SecurityManager object
			//Syntax public static SecurityManager getInstance()
			SecurityManager sMgr=SecurityManager.getInstance();
			
			// This will return RoleInfo for the specified roleId if exists or 
			// will throw exception if role with this roleId does not exists
			// public RoleInfo getRoleById(java.lang.String roleId,java.lang.String orgId,
			//                            UserInfo userInfo)throws ISecurityException
			
			//@param roleId - : Id of the requested RoleInfo object
			//@param orgId - : Organization Id of the requested role
			//@param userInfo - : The current user details 
			RoleInfo roleInfo=sMgr.getRoleById(roleId,orgId,requestorUserInfo);		
			
				
			// This will return UserInfo for the specified userId if exists or 
			// will throw exception if user with this userId does not exists
			//Syntax: public UserInfo getUserById(java.lang.String userId,java.lang.String orgId,
            //                                      UserInfo userInfo)
			UserInfo userInfo=sMgr.getUserById(userId,orgId,requestorUserInfo);
			
			
			
				// This method will grant specified role to the specified user if both role and user exists keeping previous roles in-tact. 
				// Otherwise, it will throw ISecurityException either if the user or role does not exists
				// Syntax : public void grantRoleToUser(UserInfo targetUInfo, RoleInfo rInfo, UserInfo userInfo)
                // @param targetUInfo : com.intellica.client.common.UserInfo class object to which roles has to be assigned.
				// @param rInfo - : com.intellica.client.security.RoleInfo object to be granted.
				// @param userInfo - : The details of the requesting user. 
				sMgr.grantRoleToUser(userInfo,roleInfo,requestorUserInfo);
				
			
		}
		catch(InterfaceInitException iie)
		{
		System.out.println ("Could not connect to report server::"+iie.getErrorMessage());
			
		}
		catch(ISecurityException ie)
			{
				  // Rootcause of the SecurityException sent by the report server
				System.out.println ("Error from Server:"+ie.getExtMessage());
				
			}
																			
											
		catch(Exception e)
		{
			e.printStackTrace();
		}
	}// End of main function
}		
 