// This program is to Assign multiple roles to the application user 
//The requestor user would require to provide its identity i.e. user Info to authorize for providing roles
//rights to the user

//User would require to use following Intellicus jar files for using Intellicus APIs:
//1) intellica.jar
//2) log4ij.jar
//3) xercesImpl.jar
//4) xmlParserAPIs.jar
//Place above jar files in the classpath of your application.
//These jar files are located at  :  <Install_Path>\Intellicus\APIs

/***
 * DISCLAIMER OF WARRANTY
 * This source code is provided "as is" and without warranties as to performance or merchantability. 
 * 
 * This source code is provided without any express or implied warranties whatsoever
 *
 ***/


// Import Section
// Use intellica jar to import these classes
import com.intellica.client.init.ReportClient; // Has Init Method
import com.intellica.client.common.UserInfo; // Object used to pass in run report
import com.intellica.client.security.SecurityManager;//Controller class for all security related operations  
import com.intellica.client.security.RoleInfo; // Has information about a role in the application
import com.intellica.client.exception.ISecurityException;// Exception class for all security related operations.
import com.intellica.client.exception.InterfaceInitException;//Thrown as and when there is any error
															// in initializing the report Engine interface (REInterface). 


import java.util.ArrayList;//For operations in arraylist
import java.io.FileInputStream;
import java.io.BufferedInputStream;
import java.io.InputStream;

//This class can assign a role or multiple roles to the application user.
public class AssignRolesToUser
{

	public static void main(String args[])
	{
		
		try
		{
		
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
			InputStream is= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																														//with the absolute path of ReportClient.properties.
			ReportClient.init(is);
			
								
			// Prepare a requestor user info bean object.
			// This user must have Admin rights to perform user management actions
			// such as Add role etc.
			//Syntax public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
            //@param userId   - : Id of the User Logged-In.
            //@param password - : Password of the User Logged-In.
            //@param orgId    - : Organization Id from which User Logged-In.
			String adminUserId = "Admin";
			String adminPassword = "Admin";
			String adminOrganization = "Intellica";
			UserInfo requestorUserInfo	=	new UserInfo(adminUserId,adminPassword,adminOrganization);
			
			String roleId1	="Manager";//Id of the role1 to be Assigned
			String roleId2	="Administrator";//Id of the role2 to be Assigned
			
			String userId	="TestUser";// Id of the application user
			String orgId    ="TestOrg";//Id of the organization  to which the application user belongs
			// Create a Security controller class object using its factory 
			// for user/role management related operations
			//public getInstance method to access the static instance of SecurityManager object
			//Syntax public static SecurityManager getInstance()
			SecurityManager sMgr =SecurityManager.getInstance();
			
			
			// This will return UserInfo for the specified userId if exists or 
			// will throw exception if user with this userId does not exists
			//Syntax: public UserInfo getUserById(java.lang.String userId,java.lang.String orgId,
            //                                    UserInfo userInfo) throws ISecurityException
			//@param userId - : Id of the requested UserInfo object
			//@param orgId - : Organization Id of the requested user.
			//@param userInfo - : The current user details 

			UserInfo userInfo=sMgr.getUserById(userId,orgId,requestorUserInfo);
			
			// This will return RoleInfo for the specified roleId if exists or 
			// will throw exception if role with this roleId does not exists
			// public RoleInfo getRoleById(java.lang.String roleId,java.lang.String orgId,
			//                            UserInfo userInfo)throws ISecurityException
			
			//@param roleId - : Id of the requested RoleInfo object
			//@param orgId - : Organization Id of the requested role
			//@param userInfo - : The current user details 

			RoleInfo roleInfo1=sMgr.getRoleById(roleId1,orgId,requestorUserInfo);
			RoleInfo roleInfo2=sMgr.getRoleById(roleId2,orgId,requestorUserInfo);
			
			// Create an object of ArrayList
			ArrayList roleInfoArr=new ArrayList();
			
			roleInfoArr.add(roleInfo1);//Add roleInfo object for role1 to the Array
			roleInfoArr.add(roleInfo2);//Add roleInfo object for role2 to the Array
			
			// This will Assign specified roles to the specified user if all roles and user exists or
			// will throw exception either of user or role does not exists
			// Syntax :public void assignRolesToUser(UserInfo targetUInfo,java.util.ArrayList roleInfos,UserInfo userInfo)
            //@param userInfo   -The information about the user that is the user id.
            //@param roleInfoArr-ArrayList containing the roles that are to be assigned to the user.
            //@requestorUserInfo-Contains the user info that is the current user or which has the 
            //                   right to assign roles to the user.He/she could be called as the admin. 
			sMgr.assignRolesToUser(userInfo,roleInfoArr,requestorUserInfo);	
			
																			
		}
		catch(InterfaceInitException iie)
		{
		System.out.println ("Could not connect to report server::"+iie.getErrorMessage());
			
		}
		catch(NullPointerException npe){
			System.out.println("Error Message:"+npe.getMessage());
		}
		catch(ISecurityException ie){
			 // Rootcause of the SecurityException sent by the report server
			System.out.println ("Error from Server:"+ie.getExtMessage());
			
		}									
		catch(Exception e)
		{
			e.printStackTrace();
		}
	} // End of main function
}		
 