//This Java API is used to assign the System Privileges to the User. 
//The user would require to provide its identity i.e. user Info as well as of the user 
//who is providing System Privileges.

//User would require to use following Intellicus jar files for using Intellicus APIs:
//1) intellica.jar
//2) log4ij.jar
//3) xercesImpl.jar
//4) xmlParserAPIs.jar
//Place above jar files in the classpath of your application.
//These jar files are located at  :  <Install_Path>\Intellicus\APIs

/***
 * DISCLAIMER OF WARRANTY
 * This source code is provided "as is" and without warranties as to performance or merchantability. 
 * 
 * This source code is provided without any express or implied warranties whatsoever
 *
 **/
 
 
import com.intellica.client.init.ReportClient;        // Has Init Method
import com.intellica.client.common.UserInfo;          // user info bean 
import com.intellica.client.exception.ISecurityException;// For exceptions during user management
import com.intellica.client.security.SecurityManager; // Has User management methods
import com.intellica.client.exception.InterfaceInitException;//Thrown as and when there is any error
															 // in initializing the report Engine interface (REInterface). 
import java.io.FileInputStream;
import java.io.BufferedInputStream;
import java.io.InputStream;

//This class assigns System Privileges to the user. User requires to provide its User ID so
// so to get the User instance and provide access rights to it.The required steps are :  
//1)get User Info object for the specified User Id
//2)Assign System privileges to the specified User,
public class AssignSystemPrivilegesToUser																																															
{
	public static void main(String args[])
	{
		try
		{
			
				// Static Init call. it will read the properties for report server related attributes 
				// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
				//in the INTERA_HOME property of the ReportClient.properties file.
				InputStream is= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																															//with the absolute path of ReportClient.properties.
				ReportClient.init(is);

				// Prepare a requestor user info bean object.
				// This user should be present in Intellicus application.
				//Syntax public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
                //@param userId   - : Id of the User Logged-In.
                //@param password - : Password of the User Logged-In.
                //@param orgId    - : Organization Id from which User Logged-In.
				String adminUserId = "Admin";
				String adminPassword = "Admin";
				String adminOrganization = "Intellica";
				UserInfo requestorUserInfo	=	new UserInfo(adminUserId,adminPassword,adminOrganization);
		
				// Create a SecurityManager class object 
			    // for getting the controller information for all Administration related operations
				//public getInstance method to access the static instance of SecurityManager object
				//Syntax public static SecurityManager getInstance()
				SecurityManager sMgr =SecurityManager.getInstance();
			
				// Provide the user ID of the User whose System Privileges are to be set 			
				String userId="FinanceUser";
				String OrgId="TestUser";
				
					// This will return UserInfo for the specified userId if exists or 
					// will throw exception if user with this userId does not exists
					//Syntax: public UserInfo getUserById(java.lang.String userId,java.lang.String orgId,
                    //        UserInfo userInfo)
			
					UserInfo userInfo = sMgr.getUserById(userId,OrgId,requestorUserInfo);				
				
				
					//This method is used to set the System Privileges in the comma seperated format. 
					//Syntax : public void setSystemPrivileges(java.lang.String systemPrivileges)
					userInfo.setSystemPrivileges(new com.intellica.client.utils.Utility().getRightsFromMaskedValue(
					com.intellica.client.common.Enums.SecurityTypes.SystemPrivileges.CATEGORY_SETUP |
					com.intellica.client.common.Enums.SecurityTypes.SystemPrivileges.SCHEDULER      |
					com.intellica.client.common.Enums.SecurityTypes.SystemPrivileges.REPORT_DESIGNER )); 
		   			
			    	    
					//Modifying the Access Rights of the User 
					//public void modifyUser(UserInfo targetUInfo,UserInfo userInfo)
					//@param targetUInfo - The UserInfo object containing the changed details of user 
					//@param userInfo - The current user details who is providing access rights 
					//					to the specified user.
					sMgr.modifyUser(userInfo,requestorUserInfo);
					
		}
		catch(InterfaceInitException iie)
		{
		System.out.println ("Could not connect to report server::"+iie.getErrorMessage());
		}				
		catch(ISecurityException ise)
	    {
				System.out.println ("Failed to Add user::");
				ise.printStackTrace();
		}		
		catch(Exception e)
		{
				e.printStackTrace();
		}
	} // End of main program
}		

