/* 
 * This Java API is used to get the default User Preferences set by the User.
 * User would require to use following Intellicus jar files for using Intellicus APIs:
 * 1) intellica.jar
 * 2) log4ij.jar
 * 3) xercesImpl.jar
 * 4) xmlParserAPIs.jar
 * Place above jar files in the classpath of your application.
 * These jar files are located at  :  <Install_Path>\Intellicus\APIs
 */


/***
 * DISCLAIMER OF WARRANTY
* This source code is provided "as is" and without warranties as to performance or merchantability. 
* 
* This source code is provided without any express or implied warranties whatsoever
*
**/


import com.intellica.client.common.UserInfo;// Object used to pass in run report
import com.intellica.client.exception.InterfaceInitException;//Thrown as and when there is any error
															 // in initializing the report Engine interface (REInterface).
import com.intellica.client.exception.PersonalizationHandlerException;//This Exception class is 
                                                                      //used for all Personalization use cases.
import com.intellica.client.init.ReportClient; // Has Init Method
import com.intellica.client.personalization.Preferences;//Class contains the preferences of the user
import com.intellica.client.personalization.PersonalizationManager;//This class used for User Prefernces and 
                                                                   //Dashboard related settings. It acts as the
                                                                   //manager for all the classes in this package. 
import java.io.FileInputStream;
import java.io.BufferedInputStream;
import java.io.InputStream;

/*
 * This class is used to get the Default User Preferences set by the User
 */
public class GetUserPreferences {

	public static void main(String args[])
	{
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
			InputStream is= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																														//with the absolute path of ReportClient.properties.
			ReportClient.init(is);

            //Prepare a requestor user info bean object.
			// This user must have Admin rights to perform user management actions
			// such as Add role etc.
			//Syntax public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
            //@param userId   - : Id of the User Logged-In.
            //@param password - : Password of the User Logged-In.
            //@param orgId    - : Organization Id from which User Logged-In.
			
			String adminUserId = "Admin";
			String adminPassword = "Admin";
			String adminOrganization = "Intellica";
			UserInfo requestorUserInfo	=	new UserInfo(adminUserId,adminPassword,adminOrganization);
			
			PersonalizationManager pm=new PersonalizationManager();
			//Class contains the preferences of the user. The user preferences include 
			//Preferred Language of the user. 
			//Default Theme of the user. 
			//Default deleivery location for the reports of the user. 
			//Default report format for the user. 
			//Default email address of the user. 
			//Whether to show recent reports for the user. 
			//Whether to show reports published by the user. 
			//Whether to show the inbox to user. 
			//Default stylesheet of the user. 
            Preferences userPref = null;
            //userPref.setOwnerAppId("Admin");
            userPref=  pm.getUserPreferences(requestorUserInfo);
           
            //Returns the defaultConnection
           
            String defaultCon = userPref.getDefaultConnection();
            
            //Method returns the user's preferred default portal theme 
			String  portalTheme = userPref.getDefaultPortalTheme();
			
			//Method returns default stylesheet of the user
			String defaultStylesheet = userPref.getDefaultStylesheet();
			
			//Method returns the user's preferred deliver location
			String deliveryLocation = userPref.getDeliveryLocation();
			
			//Method returns the user's preferred report format
			String defaultFormat = userPref.getFormat();
			
			//Method returns the user's preferred language
			String prefLanguage = userPref.getPrefLanguage();
			
			//Method returns the number of recent reports to be shown
			int reportCount = userPref.getReportCount();
			
			//Method returns the Boolean value whether to show the inbox or not
			Boolean showInbox = userPref.getShowInbox();
			
			//This Method returns default template name used for all reports
			String templateName = userPref.getTemplateName();
			
			// Method returns the Boolean value whether to show the recent reports or not
			Boolean showRecentReports = userPref.getShowRecentReports();
			
			//Method returns the working folder set in the user preferences.
			String workingFolder=userPref.getWorkingFolder();
			
			System.out.println("Default Connection  :  "+defaultCon);
			System.out.println("Default Portal Theme  :  "+portalTheme);
			System.out.println("Default Stylesheet  :  "+defaultStylesheet);
			System.out.println("Delivery Location  :  "+deliveryLocation);
			System.out.println("Default Format  :  "+defaultFormat);
			System.out.println("Default Preferred Language  :  "+prefLanguage);
			System.out.println("Report Count  :  "+reportCount);
			System.out.println("Show Inbox  :  "+showInbox);
			System.out.println("Template Name  :  "+templateName);
			System.out.println("Show Recent Reports  :  "+showRecentReports);
			System.out.println("Gets the Working Folder :  "+workingFolder);
			
		}
		catch(InterfaceInitException iie)
		{
		System.out.println ("Could not connect to report server::"+iie.getErrorMessage());
			
		}
		catch(PersonalizationHandlerException phe){
			System.out.println("Error Message"+phe.getExtMessage());
			
		}
		catch(Exception e)
		{
			e.printStackTrace();
		}
	}
}	
