/* 
 * This Java API is used to set the default User Preferences by the User.
 * User would require to use following Intellicus jar files for using Intellicus APIs:
 * 1) intellica.jar
 * 2) log4ij.jar
 * 3) xercesImpl.jar
 * 4) xmlParserAPIs.jar
 * Place above jar files in the classpath of your application.
 * These jar files are located at  :  <Install_Path>\Intellicus\APIs
 */


/***
 * DISCLAIMER OF WARRANTY
* This source code is provided "as is" and without warranties as to performance or merchantability. 
* 
* This source code is provided without any express or implied warranties whatsoever
*
**/

import com.intellica.client.common.InteraConstants;
import com.intellica.client.init.ReportClient; // Has Init Method
import com.intellica.client.common.UserInfo; // user info bean 
import com.intellica.client.exception.InterfaceInitException;//Thrown as and when there is any error
                                                             // in initializing the report Engine interface (REInterface).
import com.intellica.client.exception.PersonalizationHandlerException;
import com.intellica.client.personalization.PersonalizationManager;//This class used for User Prefernces and 
																	//Dashboard related settings. It acts as the
																	//manager for all the classes in this package.
import com.intellica.client.personalization.Preferences;//Class contains the preferences of the user

import java.io.FileInputStream;
import java.io.BufferedInputStream;
import java.io.InputStream;

/*
 * This class is used to set the default User Preferences by the User.
 */
public class SetUserPreferences {

	public static void main(String args[])
	{
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
			InputStream is= new BufferedInputStream(new FileInputStream("<ReportClient.properties_Absolute Path>"));//Replace by <ReportClient.properties_Absolute Path> 
																														//with the absolute path of ReportClient.properties.
			ReportClient.init(is); 
			
			
			// Prepare a requestor user info bean object.
			// This user should be present in Intellicus application.
			//Syntax public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
            //@param userId   - : Id of the User Logged-In.
            //@param password - : Password of the User Logged-In.
            //@param orgId    - : Organization Id from which User Logged-In.
			String adminUserId = "Admin";
			String adminPassword = "Admin";
			String adminOrganization = "Intellica";
			UserInfo requestorUserInfo	=	new UserInfo(adminUserId,adminPassword,adminOrganization);

			// This class used for User Prefernces and Dashboard related settings. It acts as the manager for all the classes in this package.
			// Overloaded constructor takes the report server address, TCP Socket number(port)
		    PersonalizationManager pmanager = new PersonalizationManager();
			
			//Class contains the preferences of the user. The user preferences include 
			//Preferred Language of the user. 
			//Default Theme of the user. 
			//Default deleivery location for the reports of the user. 
			//Default report format for the user. 
			//Default email address of the user. 
			//Whether to show recent reports for the user. 
			//Whether to show reports published by the user. 
			//Whether to show the inbox to user. 
			//Default stylesheet of the user. 
			Preferences pref = new Preferences();
		    pref=  pmanager.getUserPreferences(requestorUserInfo);
			pref.setReportCount(12);
			pref.setTemplateName("Beach");
			pref.setShowRecentReports(true);
			pref.setDefaultConnection("MyConnection");
			pref.setDefaultPortalTheme("Default");
			pref.setEmail("hostUser@hostOrg.com");
			pref.setFormat(InteraConstants.ReportFormats.PDF);
			pref.setPrefLanguage("EN_US");
			//Set the working folder in userpreferences.
			pref.setWorkingFolder("categoryId");
		
			//Method used to update the user preferences to the repository
			pmanager.updateUserPreferences(pref, requestorUserInfo); 
			
		}
		catch(InterfaceInitException iie)
		{
		System.out.println ("Could not connect to report server::"+iie.getErrorMessage());
			
		}
		catch(PersonalizationHandlerException phe){
			System.out.println("Error Message:"+phe.getExtMessage());
		}
		catch(Exception e)
		{
			e.printStackTrace();
		}
	}
}	
